@@ -14,9 +14,10 @@
 #include <csignal>
 #include <sys/poll.h>
 #ifdef __linux
-#include <sys/prctl.h>
-#include <sys/syscall.h>
-#include <sys/vfs.h>
+#  include <sys/prctl.h>
+#  include <sys/syscall.h>
+#  include <sys/vfs.h>
+#  include <sys/resource.h>
 #elif defined IOS
 #import <Foundation/Foundation.h>
 #endif
@@ -25,6 +26,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <dirent.h>
+#include <fcntl.h>
 
 #include <atomic>
 #include <cassert>
@@ -51,8 +53,6 @@
 #include <Poco/JSON/JSON.h>
 #include <Poco/JSON/Object.h>
 #include <Poco/JSON/Parser.h>
-#include <Poco/Net/WebSocket.h>
-#include <Poco/Process.h>
 #include <Poco/RandomStream.h>
 #include <Poco/TemporaryFile.h>
 #include <Poco/Timestamp.h>
@@ -188,14 +188,18 @@ namespace Util
             return -1;
         }
         int tasks = 0;
-        while (readdir(fdDir))
-            tasks++;
+        struct dirent *i;
+        while ((i = readdir(fdDir)))
+        {
+            if (i->d_name[0] != '.')
+                tasks++;
+        }
         closedir(fdDir);
         return tasks;
     }
 
     // close what we have - far faster than going up to a 1m open_max eg.
-    static bool closeFdsFromProc()
+    static bool closeFdsFromProc(std::map<int, int> *mapFdsToKeep = nullptr)
     {
           DIR *fdDir = opendir("/proc/self/fd");
           if (!fdDir)
@@ -219,6 +223,9 @@ namespace Util
               if (fd < 3)
                   continue;
 
+              if (mapFdsToKeep && mapFdsToKeep->find(fd) != mapFdsToKeep->end())
+                  continue;
+
               if (close(fd) < 0)
                   std::cerr << "Unexpected failure to close fd " << fd << std::endl;
           }
@@ -227,34 +234,48 @@ namespace Util
           return true;
     }
 
-    static void closeFds()
+    static void closeFds(std::map<int, int> *mapFdsToKeep = nullptr)
     {
-        if (!closeFdsFromProc())
+        if (!closeFdsFromProc(mapFdsToKeep))
         {
             std::cerr << "Couldn't close fds efficiently from /proc" << std::endl;
             for (int fd = 3; fd < sysconf(_SC_OPEN_MAX); ++fd)
-                close(fd);
+                if (mapFdsToKeep->find(fd) != mapFdsToKeep->end())
+                    close(fd);
         }
     }
 
-    int spawnProcess(const std::string &cmd, const std::vector<std::string> &args, int *stdInput)
+    int spawnProcess(const std::string &cmd, const StringVector &args, const std::vector<int>* fdsToKeep, int *stdInput)
     {
         int pipeFds[2] = { -1, -1 };
         if (stdInput)
         {
-            if (pipe(pipeFds) < 0)
+            if (pipe2(pipeFds, O_NONBLOCK) < 0)
             {
                 LOG_ERR("Out of file descriptors spawning " << cmd);
                 throw Poco::SystemException("Out of file descriptors");
             }
         }
 
+        // Create a vector of zero-terminated strings.
+        std::vector<std::string> argStrings(args.size());
+        for (const auto& arg : args)
+        {
+            argStrings.emplace_back(args.getParam(arg));
+        }
+
         std::vector<char *> params;
         params.push_back(const_cast<char *>(cmd.c_str()));
-        for (const auto& i : args)
+        for (const auto& i : argStrings)
             params.push_back(const_cast<char *>(i.c_str()));
         params.push_back(nullptr);
 
+        std::map<int, int> mapFdsToKeep;
+
+        if (fdsToKeep)
+            for (const auto& i : *fdsToKeep)
+                mapFdsToKeep[i] = i;
+
         int pid = fork();
         if (pid < 0)
         {
@@ -266,7 +287,7 @@ namespace Util
             if (stdInput)
                 dup2(pipeFds[0], STDIN_FILENO);
 
-            closeFds();
+            closeFds(&mapFdsToKeep);
 
             int ret = execvp(params[0], &params[0]);
             if (ret < 0)
@@ -282,6 +303,7 @@ namespace Util
         }
         return pid;
     }
+
 #endif
 
     bool dataFromHexString(const std::string& hexString, std::vector<unsigned char>& data)
@@ -426,7 +448,7 @@ namespace Util
         return oss.str();
     }
 
-    size_t getMemoryUsagePSS(const Poco::Process::PID pid)
+    size_t getMemoryUsagePSS(const pid_t pid)
     {
         if (pid > 0)
         {
@@ -443,7 +465,7 @@ namespace Util
         return 0;
     }
 
-    size_t getMemoryUsageRSS(const Poco::Process::PID pid)
+    size_t getMemoryUsageRSS(const pid_t pid)
     {
         static const int pageSizeBytes = getpagesize();
         size_t rss = 0;
@@ -458,7 +480,7 @@ namespace Util
         return 0;
     }
 
-    size_t getCpuUsage(const Poco::Process::PID pid)
+    size_t getCpuUsage(const pid_t pid)
     {
         if (pid > 0)
         {
@@ -470,7 +492,7 @@ namespace Util
         return 0;
     }
 
-    size_t getStatFromPid(const Poco::Process::PID pid, int ind)
+    size_t getStatFromPid(const pid_t pid, int ind)
     {
         if (pid > 0)
         {
@@ -499,6 +521,18 @@ namespace Util
         }
         return 0;
     }
+
+    void setProcessAndThreadPriorities(const pid_t pid, int prio)
+    {
+        int res = setpriority(PRIO_PROCESS, pid, prio);
+        LOG_TRC("Lowered kit [" << (int)pid << "] priority: " << prio << " with result: " << res);
+
+        // rely on Linux thread-id priority setting to drop this thread' priority
+        pid_t tid = getThreadId();
+        res = setpriority(PRIO_PROCESS, tid, prio);
+        LOG_TRC("Lowered own thread [" << (int)tid << "] priority: " << prio << " with result: " << res);
+    }
+
 #endif
 
     std::string replace(std::string result, const std::string& a, const std::string& b)
@@ -889,6 +923,70 @@ namespace Util
 
         return timestamp;
     }
+
+    std::string getSteadyClockAsString(const std::chrono::steady_clock::time_point &time)
+    {
+        auto now = std::chrono::steady_clock::now();
+        const std::time_t t = std::chrono::system_clock::to_time_t(
+            std::chrono::time_point_cast<std::chrono::seconds>(
+                std::chrono::system_clock::now() + (time - now)));
+        return std::ctime(&t);
+    }
+
+    bool isFuzzing()
+    {
+#if LIBFUZZER
+        return true;
+#else
+        return false;
+#endif
+    }
+
+    std::map<std::string, std::string> stringVectorToMap(std::vector<std::string> sVector, const char delimiter)
+    {
+        std::map<std::string, std::string> result;
+
+        for (std::vector<std::string>::iterator it = sVector.begin(); it != sVector.end(); it++)
+        {
+            size_t delimiterPosition = 0;
+            delimiterPosition = (*it).find(delimiter, 0);
+            if (delimiterPosition != std::string::npos)
+            {
+                std::string key = (*it).substr(0, delimiterPosition);
+                delimiterPosition++;
+                std::string value = (*it).substr(delimiterPosition);
+                result[key] = value;
+            }
+            else
+            {
+                LOG_WRN("Util::stringVectorToMap => record is misformed: " << (*it));
+            }
+        }
+
+        return result;
+    }
+
+    #if !MOBILEAPP
+        // If OS is not mobile, it must be Linux.
+        std::string getLinuxVersion(){
+            // Read operating system info. We can read "os-release" file, located in /etc.
+            std::ifstream ifs("/etc/os-release");
+            std::string str(std::istreambuf_iterator<char>{ifs}, {});
+            std::vector<std::string> infoList = Util::splitStringToVector(str, '\n');
+            std::map<std::string, std::string> releaseInfo = Util::stringVectorToMap(infoList, '=');
+
+            auto it = releaseInfo.find("PRETTY_NAME");
+            if (it != releaseInfo.end())
+            {
+                return it->second;
+            }
+            else
+            {
+                return "unknown";
+            }
+        }
+    #endif
+
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
