@@ -24,111 +24,128 @@
 #include <cstring>
 #include <iostream>
 #include <map>
+#include <thread>
+#include <chrono>
 
 #include <Poco/Path.h>
-#include <Poco/Process.h>
-#include <Poco/Thread.h>
 
 #include <Common.hpp>
-#include <IoUtil.hpp>
 #include "Kit.hpp"
 #include <Log.hpp>
 #include <Unit.hpp>
 #include <Util.hpp>
+#include <WebSocketHandler.hpp>
+#if !MOBILEAPP
+#include <Admin.hpp>
+#endif
 
 #include <common/FileUtil.hpp>
 #include <common/Seccomp.hpp>
 #include <common/SigUtil.hpp>
 #include <security.h>
 
-using Poco::Process;
-using Poco::Thread;
-
 #ifndef KIT_IN_PROCESS
 static bool NoCapsForKit = false;
 static bool NoSeccomp = false;
+#if ENABLE_DEBUG
+static bool SingleKit = false;
 #endif
+#endif
+
 static bool DisplayVersion = false;
 static std::string UnitTestLibrary;
 static std::string LogLevel;
 static std::atomic<unsigned> ForkCounter(0);
 
-static std::map<Process::PID, std::string> childJails;
+static std::map<pid_t, std::string> childJails;
 
 #ifndef KIT_IN_PROCESS
 int ClientPortNumber = DEFAULT_CLIENT_PORT_NUMBER;
 std::string MasterLocation;
 #endif
 
-/// Dispatcher class to demultiplex requests from
-/// WSD and handles them.
-class CommandDispatcher : public IoUtil::PipeReader
+class ServerWSHandler;
+
+// We have a single thread and a single connection so we won't bother with
+// access synchronization
+std::shared_ptr<ServerWSHandler> WSHandler;
+
+class ServerWSHandler final : public WebSocketHandler
 {
+    std::string _socketName;
+
 public:
-    CommandDispatcher(const int pipe) :
-        PipeReader("wsd_pipe_rd", pipe)
+    ServerWSHandler(const std::string& socketName) :
+        WebSocketHandler(/* isClient = */ true, /* isMasking */ false),
+        _socketName(socketName)
     {
     }
 
-    /// Polls WSD commands and handles them.
-    bool pollAndDispatch()
+protected:
+    void handleMessage(const std::vector<char>& data) override
     {
-        std::string message;
-        const int ready = readLine(message, [](){ return SigUtil::getTerminationFlag(); });
-        if (ready <= 0)
-        {
-            // Termination is done via SIGTERM, which breaks the wait.
-            if (ready < 0)
-            {
-                if (SigUtil::getTerminationFlag())
-                {
-                    LOG_INF("Poll interrupted in " << getName() << " and TerminationFlag is set.");
-                }
+        std::string message(data.data(), data.size());
 
-                // Break.
-                return false;
+#if !MOBILEAPP
+        if (UnitKit::get().filterKitMessage(this, message))
+            return;
+#endif
+        StringVector tokens = LOOLProtocol::tokenize(message);
+        Log::StreamLogger logger = Log::debug();
+        if (logger.enabled())
+        {
+            logger << _socketName << ": recv [";
+            for (const auto& token : tokens)
+            {
+                logger << tokens.getParam(token) << ' ';
             }
 
-            // Timeout.
-            return true;
+            LOG_END(logger, true);
         }
 
-        LOG_INF("ForKit command: [" << message << "].");
-        try
+        // Note: Syntax or parsing errors here are unexpected and fatal.
+        if (SigUtil::getTerminationFlag())
         {
-            std::vector<std::string> tokens = LOOLProtocol::tokenize(message);
-            if (tokens.size() == 2 && tokens[0] == "spawn")
+            LOG_DBG("Termination flag set: skip message processing");
+        }
+        else if (tokens.size() == 2 && tokens.equals(0, "spawn"))
+        {
+            const int count = std::stoi(tokens[1]);
+            if (count > 0)
             {
-                const int count = std::stoi(tokens[1]);
-                if (count > 0)
-                {
-                    LOG_INF("Setting to spawn " << tokens[1] << " child" << (count == 1 ? "" : "ren") << " per request.");
-                    ForkCounter = count;
-                }
-                else
-                {
-                    LOG_WRN("Cannot spawn " << tokens[1] << " children as requested.");
-                }
-            }
-            else if (tokens.size() == 3 && tokens[0] == "setconfig")
-            {
-                // Currently only rlimit entries are supported.
-                if (!Rlimit::handleSetrlimitCommand(tokens))
-                {
-                    LOG_ERR("Unknown setconfig command: " << message);
-                }
+                LOG_INF("Setting to spawn " << tokens[1] << " child" << (count == 1 ? "" : "ren") << " per request.");
+                ForkCounter = count;
             }
             else
             {
-                LOG_ERR("Unknown command: " << message);
+                LOG_WRN("Cannot spawn " << tokens[1] << " children as requested.");
             }
         }
-        catch (const std::exception& exc)
+        else if (tokens.size() == 3 && tokens.equals(0, "setconfig"))
         {
-            LOG_ERR("Error while processing forkit request [" << message << "]: " << exc.what());
+            // Currently only rlimit entries are supported.
+            if (!Rlimit::handleSetrlimitCommand(tokens))
+            {
+                LOG_ERR("Unknown setconfig command: " << message);
+            }
         }
+        else if (tokens.equals(0, "exit"))
+        {
+            LOG_INF("Setting TerminationFlag due to 'exit' command from parent.");
+            SigUtil::setTerminationFlag();
+        }
+        else
+        {
+            LOG_ERR("Bad or unknown token [" << tokens[0] << "]");
+        }
+    }
 
-        return true;
+    void onDisconnect() override
+    {
+#if !MOBILEAPP
+        LOG_WRN("ForKit connection lost without exit arriving from wsd. Setting TerminationFlag");
+        SigUtil::setTerminationFlag();
+#endif
     }
 };
 
@@ -207,8 +224,9 @@ static bool haveCorrectCapabilities()
 static void cleanupChildren()
 {
     std::vector<std::string> jails;
-    Process::PID exitedChildPid;
-    int status;
+    pid_t exitedChildPid;
+    int status, segFaultCount = 0;
+
     // Reap quickly without doing slow cleanup so WSD can spawn more rapidly.
     while ((exitedChildPid = waitpid(-1, &status, WUNTRACED | WNOHANG)) > 0)
     {
@@ -223,6 +241,11 @@ static void cleanupChildren()
                 // We ran out of kits and we aren't terminating.
                 LOG_WRN("No live Kits exist, and we are not terminating yet.");
             }
+
+            if (WIFSIGNALED(status) && (WTERMSIG(status) == SIGSEGV || WTERMSIG(status) == SIGBUS))
+            {
+                segFaultCount ++;
+            }
         }
         else
         {
@@ -230,6 +253,30 @@ static void cleanupChildren()
         }
     }
 
+    if (segFaultCount)
+    {
+#ifdef KIT_IN_PROCESS
+#if !MOBILEAPP
+        Admin::instance().addSegFaultCount(segFaultCount);
+#endif
+#else
+        if (WSHandler)
+        {
+            std::stringstream stream;
+            stream << "segfaultcount " << segFaultCount << "\n";
+            int ret = WSHandler->sendMessage(stream.str());
+            if (ret == -1)
+            {
+                LOG_WRN("Could not send 'segfaultcount' message through websocket");
+            }
+            else
+            {
+                LOG_WRN("Successfully sent 'segfaultcount' message " << stream.str());
+            }
+        }
+#endif
+    }
+
     // Now delete the jails.
     for (const auto& path : jails)
     {
@@ -252,7 +299,7 @@ static int createLibreOfficeKit(const std::string& childRoot,
     ++spareKitId;
     LOG_DBG("Forking a loolkit process with jailId: " << jailId << " as spare loolkit #" << spareKitId << ".");
 
-    const Process::PID pid = fork();
+    const pid_t pid = fork();
     if (!pid)
     {
         // Child
@@ -271,8 +318,8 @@ static int createLibreOfficeKit(const std::string& childRoot,
             {
                 std::cerr << "Kit: Sleeping " << delaySecs
                           << " seconds to give you time to attach debugger to process "
-                          << Process::id() << std::endl;
-                Thread::sleep(delaySecs * 1000);
+                          << getpid() << std::endl;
+                std::this_thread::sleep_for(std::chrono::seconds(delaySecs));
             }
         }
 
@@ -348,7 +395,20 @@ static void printArgumentHelp()
 
 int main(int argc, char** argv)
 {
-    if (!hasCorrectUID("loolforkit"))
+    // early check for avoiding the security check for username 'lool'
+    // (deliberately only this, not moving the entire parameter parsing here)
+    bool checkLoolUser = true;
+    for (int i = 0; i < argc; ++i)
+    {
+        char *cmd = argv[i];
+        if (std::strstr(cmd, "--disable-lool-user-checking") == cmd)
+        {
+            std::cerr << "Security: Check for the 'lool' username overridden on the command line." << std::endl;
+            checkLoolUser = false;
+        }
+    }
+
+    if (checkLoolUser && !hasCorrectUID("loolforkit"))
     {
         return EX_SOFTWARE;
     }
@@ -360,8 +420,8 @@ int main(int argc, char** argv)
         {
             std::cerr << "Forkit: Sleeping " << delaySecs
                       << " seconds to give you time to attach debugger to process "
-                      << Process::id() << std::endl;
-            Thread::sleep(delaySecs * 1000);
+                      << getpid() << std::endl;
+            std::this_thread::sleep_for(std::chrono::seconds(delaySecs));
         }
     }
 
@@ -395,15 +455,6 @@ int main(int argc, char** argv)
     std::string sysTemplate;
     std::string loTemplate;
 
-#if ENABLE_DEBUG
-    static const char* clientPort = std::getenv("LOOL_TEST_CLIENT_PORT");
-    if (clientPort)
-        ClientPortNumber = std::stoi(clientPort);
-    static const char* masterPort = std::getenv("LOOL_TEST_MASTER_PORT");
-    if (masterPort)
-        MasterLocation = masterPort;
-#endif
-
     for (int i = 0; i < argc; ++i)
     {
         char *cmd = argv[i];
@@ -449,14 +500,17 @@ int main(int argc, char** argv)
         {
             eq = std::strchr(cmd, '=');
             const std::string rlimits = std::string(eq+1);
-            std::vector<std::string> tokens = LOOLProtocol::tokenize(rlimits, ';');
-            for (const std::string& cmdLimit : tokens)
+            StringVector tokens = LOOLProtocol::tokenize(rlimits, ';');
+            for (const auto& cmdLimit : tokens)
             {
-                const std::pair<std::string, std::string> pair = Util::split(cmdLimit, ':');
-                std::vector<std::string> tokensLimit = { "setconfig", pair.first, pair.second };
+                const std::pair<std::string, std::string> pair = Util::split(tokens.getParam(cmdLimit), ':');
+                StringVector tokensLimit;
+                tokensLimit.push_back("setconfig");
+                tokensLimit.push_back(pair.first);
+                tokensLimit.push_back(pair.second);
                 if (!Rlimit::handleSetrlimitCommand(tokensLimit))
                 {
-                    LOG_ERR("Unknown rlimits command: " << cmdLimit);
+                    LOG_ERR("Unknown rlimits command: " << tokens.getParam(cmdLimit));
                 }
             }
         }
@@ -467,6 +521,10 @@ int main(int argc, char** argv)
             eq = std::strchr(cmd, '=');
             UnitTestLibrary = std::string(eq+1);
         }
+        else if (std::strstr(cmd, "--singlekit") == cmd)
+        {
+            SingleKit = true;
+        }
 #endif
         // we are running in a lower-privilege mode - with no chroot
         else if (std::strstr(cmd, "--nocaps") == cmd)
@@ -478,7 +536,7 @@ int main(int argc, char** argv)
         // we are running without seccomp protection
         else if (std::strstr(cmd, "--noseccomp") == cmd)
         {
-            LOG_ERR("Security :Running without the ability to filter system calls is ill advised.");
+            LOG_ERR("Security: Running without the ability to filter system calls is ill advised.");
             NoSeccomp = true;
         }
     }
@@ -497,25 +555,7 @@ int main(int argc, char** argv)
         return EX_USAGE;
     }
 
-    // Setup & check environment
-    const std::string layers(
-        "xcsxcu:${BRAND_BASE_DIR}/share/registry "
-        "res:${BRAND_BASE_DIR}/share/registry "
-        "bundledext:${${BRAND_BASE_DIR}/program/lounorc:BUNDLED_EXTENSIONS_USER}/registry/com.sun.star.comp.deployment.configuration.PackageRegistryBackend/configmgr.ini "
-        "sharedext:${${BRAND_BASE_DIR}/program/lounorc:SHARED_EXTENSIONS_USER}/registry/com.sun.star.comp.deployment.configuration.PackageRegistryBackend/configmgr.ini "
-        "userext:${${BRAND_BASE_DIR}/program/lounorc:UNO_USER_PACKAGES_CACHE}/registry/com.sun.star.comp.deployment.configuration.PackageRegistryBackend/configmgr.ini "
-#if ENABLE_DEBUG // '*' denotes non-writable.
-        "user:*file://" DEBUG_ABSSRCDIR "/loolkitconfig.xcu "
-#else
-        "user:*file://" LOOLWSD_CONFIGDIR "/loolkitconfig.xcu "
-#endif
-        );
-
-    // No-caps tracing can spawn eg. glxinfo & other oddness.
-    unsetenv("DISPLAY");
-
-    ::setenv("CONFIGURATION_LAYERS", layers.c_str(),
-             1 /* override */);
+    setupKitEnvironment();
 
     if (!std::getenv("LD_BIND_NOW")) // must be set by parent.
         LOG_INF("Note: LD_BIND_NOW is not set.");
@@ -528,13 +568,6 @@ int main(int argc, char** argv)
         return EX_SOFTWARE;
     }
 
-    // Set various options we need.
-    std::string options = "unipoll";
-    if (Log::logger().trace())
-        options += ":profile_events";
-//    options += ":sc_no_grid_bg"; // leave ths disabled for now, merged-cells needs more work.
-    ::setenv("SAL_LOK_OPTIONS", options.c_str(), 0);
-
     // Initialize LoKit
     if (!globalPreinit(loTemplate))
     {
@@ -551,7 +584,7 @@ int main(int argc, char** argv)
     // We must have at least one child, more are created dynamically.
     // Ask this first child to send version information to master process and trace startup.
     ::setenv("LOOL_TRACE_STARTUP", "1", 1);
-    Process::PID forKitPid = createLibreOfficeKit(childRoot, sysTemplate, loTemplate, loSubPath, true);
+    pid_t forKitPid = createLibreOfficeKit(childRoot, sysTemplate, loTemplate, loSubPath, true);
     if (forKitPid < 0)
     {
         LOG_FTL("Failed to create a kit process.");
@@ -567,19 +600,26 @@ int main(int argc, char** argv)
         Log::logger().setLevel(LogLevel);
     }
 
-    CommandDispatcher commandDispatcher(0);
+    SocketPoll mainPoll(Util::getThreadName());
+    mainPoll.runOnClientThread(); // We will do the polling on this thread.
+
+    WSHandler = std::make_shared<ServerWSHandler>("forkit_ws");
+
+#if !MOBILEAPP
+    mainPoll.insertNewUnixSocket(MasterLocation, FORKIT_URI, WSHandler);
+#endif
+
     LOG_INF("ForKit process is ready.");
 
     while (!SigUtil::getTerminationFlag())
     {
         UnitKit::get().invokeForKitTest();
 
-        if (!commandDispatcher.pollAndDispatch())
-        {
-            LOG_INF("Child dispatcher flagged for termination.");
-            break;
-        }
+        mainPoll.poll(POLL_TIMEOUT_MICRO_S);
 
+#if ENABLE_DEBUG
+        if (!SingleKit)
+#endif
         forkLibreOfficeKit(childRoot, sysTemplate, loTemplate, loSubPath);
     }
 
