@@ -3,7 +3,7 @@
  * L.Control.RowHeader
 */
 
-/* global $ _UNO */
+/* global $ _UNO Hammer */
 L.Control.RowHeader = L.Control.Header.extend({
 	options: {
 		cursor: 'row-resize'
@@ -60,94 +60,93 @@ L.Control.RowHeader = L.Control.Header.extend({
 		this._startOffset = 0;
 		this._position = 0;
 
-		var rowHeaderObj = this;
-		L.installContextMenu({
-			selector: '.spreadsheet-header-rows',
-			className: 'loleaflet-font',
-			items: {
-				'insertrowabove': {
-					name: _UNO('.uno:InsertRowsBefore', 'spreadsheet', true),
-					callback: function() {
-						var index = rowHeaderObj._lastMouseOverIndex;
-						if (index) {
-							rowHeaderObj.insertRow.call(rowHeaderObj, index);
-						}
-					}
-				},
-				'deleteselectedrow': {
-					name: _UNO('.uno:DeleteRows', 'spreadsheet', true),
-					callback: function() {
-						var index = rowHeaderObj._lastMouseOverIndex;
-						if (index) {
-							rowHeaderObj.deleteRow.call(rowHeaderObj, index);
-						}
-					}
-				},
-				'optimalheight': {
-					name: _UNO('.uno:SetOptimalRowHeight', 'spreadsheet', true),
-					callback: function() {
-						var index = rowHeaderObj._lastMouseOverIndex;
-						if (index) {
-							rowHeaderObj.optimalHeight.call(rowHeaderObj, index);
-						}
-					}
-				},
-				'hideRow': {
-					name: _UNO('.uno:HideRow', 'spreadsheet', true),
-					callback: function() {
-						var index = rowHeaderObj._lastMouseOverIndex;
-						if (index) {
-							rowHeaderObj.hideRow.call(rowHeaderObj, index);
-						}
-					}
-				},
-				'showRow': {
-					name: _UNO('.uno:ShowRow', 'spreadsheet', true),
-					callback: function() {
-						var index = rowHeaderObj._lastMouseOverIndex;
-						if (index) {
-							rowHeaderObj.showRow.call(rowHeaderObj, index);
-						}
-					}
-				}
+		this._menuItem = {
+			'.uno:InsertRowsBefore': {
+				name: _UNO('.uno:InsertRowsBefore', 'spreadsheet', true),
+				callback: (this._insertRowAbove).bind(this)
 			},
-			zIndex: 10
-		});
+			'.uno:InsertRowsAfter': {
+				name: _UNO('.uno:InsertRowsAfter', 'spreadsheet', true),
+				callback: (this._insertRowBelow).bind(this)
+			},
+			'.uno:DeleteRows': {
+				name: _UNO('.uno:DeleteRows', 'spreadsheet', true),
+				callback: (this._deleteSelectedRow).bind(this)
+			},
+			'.uno:SetOptimalRowHeight': {
+				name: _UNO('.uno:SetOptimalRowHeight', 'spreadsheet', true),
+				callback: (this._optimalHeight).bind(this)
+			},
+			'.uno:HideRow': {
+				name: _UNO('.uno:HideRow', 'spreadsheet', true),
+				callback: (this._hideRow).bind(this)
+			},
+			'.uno:ShowRow': {
+				name: _UNO('.uno:ShowRow', 'spreadsheet', true),
+				callback: (this._showRow).bind(this)
+			}
+		};
+
+		if (!window.mode.isMobile()) {
+			L.installContextMenu({
+				selector: '.spreadsheet-header-rows',
+				className: 'loleaflet-font',
+				items: this._menuItem,
+				zIndex: 10
+			});
+		} else {
+			var menuData = L.Control.JSDialogBuilder.getMenuStructureForMobileWizard(this._menuItem, true, '');
+			(new Hammer(this._canvas, {recognizers: [[Hammer.Press]]}))
+			.on('press', L.bind(function () {
+				if (this._map._permission === 'edit') {
+					window.contextMenuWizard = true;
+					this._map.fire('mobilewizard', menuData);
+				}
+			}, this));
+		}
+
 	},
 
 	optimalHeight: function(index) {
-		if (this._map._docLayer._selections.getLayers().length === 0) {
+		if (!this.isHighlighted(index)) {
 			this._selectRow(index, 0);
 		}
 		this._map.sendUnoCommand('.uno:SetOptimalRowHeight');
 	},
 
-	insertRow: function(index) {
+	insertRowAbove: function(index) {
 		// First select the corresponding row because
 		// .uno:InsertRows doesn't accept any row number
 		// as argument and just inserts before the selected row
-		if (this._map._docLayer._selections.getLayers().length === 0) {
+		if (!this.isHighlighted(index)) {
 			this._selectRow(index, 0);
 		}
 		this._map.sendUnoCommand('.uno:InsertRows');
 	},
 
+	insertRowBelow: function(index) {
+		if (!this.isHighlighted(index)) {
+			this._selectRow(index, 0);
+		}
+		this._map.sendUnoCommand('.uno:InsertRowsAfter');
+	},
+
 	deleteRow: function(index) {
-		if (this._map._docLayer._selections.getLayers().length === 0) {
+		if (!this.isHighlighted(index)) {
 			this._selectRow(index, 0);
 		}
 		this._map.sendUnoCommand('.uno:DeleteRows');
 	},
 
 	hideRow: function(index) {
-		if (this._map._docLayer._selections.getLayers().length === 0) {
+		if (!this.isHighlighted(index)) {
 			this._selectRow(index, 0);
 		}
 		this._map.sendUnoCommand('.uno:HideRow');
 	},
 
 	showRow: function(index) {
-		if (this._map._docLayer._selections.getLayers().length === 0) {
+		if (!this.isHighlighted(index)) {
 			this._selectRow(index, 0);
 		}
 		this._map.sendUnoCommand('.uno:ShowRow');
@@ -243,13 +242,13 @@ L.Control.RowHeader = L.Control.Header.extend({
 			var w = width - 4;
 			var size = 2;
 			var offset = 1;
-			ctx.fillStyle = '#BBBBBB'
+			ctx.fillStyle = '#BBBBBB';
 			ctx.fillRect(x + 2, center - size - offset, w - 4, size);
 			ctx.fillRect(x + 2, center + offset, w - 4, size);
 		}
 		// draw text content
 		ctx.fillStyle = isHighlighted ? this._selectionTextColor : this._textColor;
-		ctx.font = this._font;
+		ctx.font = this._font.getFont();
 		ctx.textAlign = 'center';
 		ctx.textBaseline = 'middle';
 		ctx.fillText(content, startOrt + (width / 2), endPar - (height / 2));
@@ -337,7 +336,7 @@ L.Control.RowHeader = L.Control.Header.extend({
 		ctx.strokeRect(startOrt, startPar, ctrlHeadSize, ctrlHeadSize);
 		// draw level number
 		ctx.fillStyle = this._textColor;
-		ctx.font = this._font;
+		ctx.font = this._font.getFont();
 		ctx.textAlign = 'center';
 		ctx.textBaseline = 'middle';
 		ctx.fillText(level + 1, startOrt + (ctrlHeadSize / 2), startPar + (ctrlHeadSize / 2));
@@ -384,7 +383,9 @@ L.Control.RowHeader = L.Control.Header.extend({
 		this._current = -1;
 		this._selection.start = this._selection.end = -1;
 		this._mouseOverEntry = null;
-		this._lastMouseOverIndex = undefined;
+		if (!window.contextMenuWizard) {
+			this._lastMouseOverIndex = undefined;
+		}
 
 		// create data structure for row heights
 		this._tickMap = new L.Control.Header.GapTickMap(this._map, rows);
@@ -419,7 +420,6 @@ L.Control.RowHeader = L.Control.Header.extend({
 
 		this.mouseInit(canvas);
 
-		L.DomEvent.on(canvas, 'contextmenu', L.DomEvent.preventDefault);
 		if ($('.spreadsheet-header-rows').length > 0) {
 			$('.spreadsheet-header-rows').contextMenu(this._map._permission === 'edit');
 		}
@@ -618,6 +618,48 @@ L.Control.RowHeader = L.Control.Header.extend({
 		this._setCanvasWidth(width);
 
 		this._map.fire('updatecornerheader');
+	},
+
+	_insertRowAbove: function() {
+		var index = this._lastMouseOverIndex;
+		if (index) {
+			this.insertRowAbove.call(this, index);
+		}
+	},
+
+	_insertRowBelow: function() {
+		var index = this._lastMouseOverIndex;
+		if (index) {
+			this.insertRowBelow.call(this, index);
+		}
+	},
+
+	_deleteSelectedRow: function() {
+		var index = this._lastMouseOverIndex;
+		if (index) {
+			this.deleteRow.call(this, index);
+		}
+	},
+
+	_optimalHeight: function() {
+		var index = this._lastMouseOverIndex;
+		if (index) {
+			this.optimalHeight.call(this, index);
+		}
+	},
+
+	_hideRow: function() {
+		var index = this._lastMouseOverIndex;
+		if (index) {
+			this.hideRow.call(this, index);
+		}
+	},
+
+	_showRow: function() {
+		var index = this._lastMouseOverIndex;
+		if (index) {
+			this.showRow.call(this, index);
+		}
 	}
 });
 
