@@ -77,7 +77,6 @@ L.AnnotationManager = L.Class.extend({
 				opacity: 0.25
 			});
 			comment.textSelected.addEventParent(this._map);
-			L.DomEvent.on(comment.textSelected, 'contextmenu', L.DomEvent.preventDefault);
 			comment.textSelected.on('click', function() {
 				this.selectById(comment.id);
 			}, this);
@@ -106,7 +105,6 @@ L.AnnotationManager = L.Class.extend({
 				opacity: 0
 			});
 			redline.textSelected.addEventParent(this._map);
-			L.DomEvent.on(redline.textSelected, 'contextmenu', L.DomEvent.preventDefault);
 			redline.textSelected.on('click', function() {
 				this.selectById(redline.id);
 			}, this);
@@ -908,7 +906,7 @@ L.AnnotationManager = L.Class.extend({
 	},
 
 	_getScaleFactor: function () {
-		var scaleFactor = 1.0 / this._map.getZoomScale(this._map.options.zoom, this._map._zoom);
+		var scaleFactor = 1.0 / this._map.getZoomScale(this._map.options.zoom, this._map.getZoom());
 		if (scaleFactor < 0.4)
 			scaleFactor = 0.4;
 		else if (scaleFactor < 0.6)
@@ -926,7 +924,7 @@ L.AnnotationManager = L.Class.extend({
 	},
 
 	_updateScaling: function () {
-		if (!L.Browser.mobile || this._items.length === 0)
+		if (window.mode.isDesktop() || this._items.length === 0)
 			return;
 		var contentWrapperClassName, menuClassName;
 		if (this._items[0]._data.trackchange) {
