@@ -3,16 +3,18 @@
  * Impress tile layer is used to display a presentation document
  */
 
-/* global $ _ w2ui w2utils _UNO L */
+/* global $ L */
 
 L.ImpressTileLayer = L.TileLayer.extend({
 	extraSize: L.point(290, 0),
 
 	initialize: function (url, options) {
 		L.TileLayer.prototype.initialize.call(this, url, options);
+		this._preview = L.control.partsPreview();
 
 		if (window.mode.isMobile()) {
 			this._addButton = L.control.mobileSlide();
+			L.DomUtil.addClass(L.DomUtil.get('mobile-edit-button'), 'impress');
 		}
 	},
 
@@ -37,7 +39,7 @@ L.ImpressTileLayer = L.TileLayer.extend({
 	},
 
 	beforeAdd: function (map) {
-		map.addControl(L.control.partsPreview());
+		map.addControl(this._preview);
 		map.on('zoomend', this._onAnnotationZoom, this);
 		map.on('updateparts', this.onUpdateParts, this);
 		map.on('updatepermission', this.onUpdatePermission, this);
@@ -48,8 +50,10 @@ L.ImpressTileLayer = L.TileLayer.extend({
 		map.on('AnnotationScrollDown', this.onAnnotationScrollDown, this);
 		map.on('orientationchange', this.onOrientationChange, this);
 		map.on('resize', this.onResize, this);
+
+		map.uiManager.initializeSpecializedUI('presentation');
+
 		if (window.mode.isMobile()) {
-			this.onMobileInit(map);
 			L.Control.MobileWizard.mergeOptions({maxHeight: '55%'});
 			var mobileWizard = L.DomUtil.get('mobile-wizard');
 			var mobileWizardContent = L.DomUtil.get('mobile-wizard-content');
@@ -92,14 +96,15 @@ L.ImpressTileLayer = L.TileLayer.extend({
 	},
 
 	onResize: function () {
-		if (!L.Browser.mobile) {
+		if (window.mode.isDesktop()) {
 			this._map.setView(this._map.getCenter(), this._map.getZoom(), {reset: true});
 		}
 
-		var presentationControlWrapperElem = L.DomUtil.get('presentation-controls-wrapper');
-		var visible = L.DomUtil.getStyle(presentationControlWrapperElem, 'display');
+		L.DomUtil.updateElementsOrientation(['presentation-controls-wrapper', 'document-container', 'slide-sorter', 'mobile-wizard-header', 'mobile-wizard-content']);
 
-		if (!this._isSlidePaneVisible && visible !== 'none') {
+		// update parts
+		var visible = L.DomUtil.getStyle(L.DomUtil.get('presentation-controls-wrapper'), 'display');
+		if (visible !== 'none') {
 			this._map.fire('updateparts', {
 				selectedPart: this._selectedPart,
 				selectedParts: this._selectedParts,
@@ -108,179 +113,6 @@ L.ImpressTileLayer = L.TileLayer.extend({
 				partNames: this._partHashes
 			});
 		}
-		this._isSlidePaneVisible = !(visible === 'none');
-	},
-
-	onMobileInit: function (map) {
-		var toolItems = [
-			{type: 'button',  id: 'showsearchbar',  img: 'search', hint: _('Show the search bar')},
-			{type: 'break'},
-			{type: 'button',  id: 'bold',  img: 'bold', hint: _UNO('.uno:Bold'), uno: 'Bold'},
-//			{type: 'button',  id: 'italic', img: 'italic', hint: _UNO('.uno:Italic'), uno: 'Italic'},
-			{type: 'button',  id: 'underline',  img: 'underline', hint: _UNO('.uno:Underline'), uno: 'Underline'},
-			{type: 'button',  id: 'strikeout', img: 'strikeout', hint: _UNO('.uno:Strikeout'), uno: 'Strikeout'},
-			{type: 'text-color',  id: 'fontcolor', img: 'textcolor', hint: _UNO('.uno:FontColor')},
-			{type: 'color',  id: 'backcolor', img: 'backcolor', hint: _UNO('.uno:BackgroundColor')},
-			{type: 'menu', id: 'textalign', img: 'alignblock', hint: _UNO('.uno:TextAlign'),
-				items: [
-					{id: 'leftpara',    text: _UNO('.uno:LeftPara', '', true),    icon: 'alignleft', uno: 'LeftPara'},
-					{id: 'centerpara',  text: _UNO('.uno:CenterPara', '', true),  icon: 'alignhorizontal', uno: 'CenterPara'},
-					{id: 'rightpara',   text: _UNO('.uno:RigthPara', '', true),   icon: 'alignright', uno: 'RightPara'},
-					{id: 'justifypara', text: _UNO('.uno:JustifyPara', '', true), icon: 'alignblock', uno: 'JustifyPara'},
-				]},
-			{type: 'menu',  id: 'linespacing',  img: 'linespacing', hint: _UNO('.uno:FormatSpacingMenu'),
-				items: [
-					{id: 'spacepara1', text: _UNO('.uno:SpacePara1'), uno: 'SpacePara1'},
-					{id: 'spacepara15', text: _UNO('.uno:SpacePara15'), uno: 'SpacePara15'},
-					{id: 'spacepara2', text: _UNO('.uno:SpacePara2'), uno: 'SpacePara2'},
-					{type: 'break'},
-					{id: 'paraspaceincrease', text: _UNO('.uno:ParaspaceIncrease'), uno: 'ParaspaceIncrease'},
-					{id: 'paraspacedecrease', text: _UNO('.uno:ParaspaceDecrease'), uno: 'ParaspaceDecrease'}
-				]},
-			{type: 'button',  id: 'defaultbullet',  img: 'bullet', hint: _UNO('.uno:DefaultBullet', '', true), uno: 'DefaultBullet', disabled: true},
-		];
-
-		var toolbar = $('#toolbar-up');
-		toolbar.w2toolbar({
-			name: 'actionbar',
-			tooltip: 'bottom',
-			items: [
-				{type: 'button',  id: 'closemobile',  img: 'closemobile'},
-				{type: 'spacer'},
-				{type: 'button',  id: 'undo',  img: 'undo', hint: _UNO('.uno:Undo'), uno: 'Undo', disabled: true},
-				{type: 'button',  id: 'redo',  img: 'redo', hint: _UNO('.uno:Redo'), uno: 'Redo', disabled: true},
-				{type: 'button',  id: 'fullscreen-presentation', img: 'fullscreen-presentation', hint: _UNO('.uno:FullScreen', 'presentation')},
-				{type: 'button',  id: 'mobile_wizard', img: 'mobile_wizard', disabled: true},
-				{type: 'button',  id: 'insertion_mobile_wizard', img: 'insertion_mobile_wizard', disabled: true},
-				{type: 'button',  id: 'insertcomment', img: 'insertcomment', disabled: true},
-				{type: 'drop', id: 'userlist', img: 'users', hidden: true, html: '<div id="userlist_container"><table id="userlist_table"><tbody></tbody></table>' +
-					'<hr><table class="loleaflet-font" id="editor-btn">' +
-					'<tr>' +
-					'<td><input type="checkbox" name="alwaysFollow" id="follow-checkbox" onclick="editorUpdate(event)"></td>' +
-					'<td>' + _('Always follow the editor') + '</td>' +
-					'</tr>' +
-					'</table>' +
-					'<p id="currently-msg">' + _('Current') + ' - <b><span id="current-editor"></span></b></p>' +
-					'</div>'
-				},
-			],
-			onClick: function (e) {
-				window.onClick(e, e.target);
-				window.hideTooltip(this, e.target);
-			},
-			onRefresh: function() {
-				var showUserList = map['wopi'].HideUserList !== null &&
-									map['wopi'].HideUserList !== undefined &&
-									$.inArray('true', map['wopi'].HideUserList) < 0 &&
-									((window.mode.isMobile() && $.inArray('mobile', map['wopi'].HideUserList) < 0) ||
-									(window.mode.isTablet() && $.inArray('tablet', map['wopi'].HideUserList) < 0));
-				if (this.get('userlist').hidden == true && showUserList) {
-					this.show('userlist');
-					this.show('userlistbreak');
-					map.on('deselectuser', window.deselectUser);
-					map.on('addview', window.onAddView);
-					map.on('removeview', window.onRemoveView);
-				}
-			}
-		});
-		toolbar.bind('touchstart', function(e) {
-			w2ui['actionbar'].touchStarted = true;
-			var touchEvent = e.originalEvent;
-			if (touchEvent && touchEvent.touches.length > 1) {
-				L.DomEvent.preventDefault(e);
-			}
-		});
-
-		toolbar = $('#presentation-toolbar');
-		toolbar.w2toolbar({
-			name: 'presentation-toolbar',
-			tooltip: 'bottom',
-			hidden: true,
-			items: []
-		});
-
-		toolbar = $('#toolbar-down');
-		toolbar.w2toolbar({
-			name: 'editbar',
-			tooltip: 'top',
-			items: toolItems,
-			onClick: function (e) {
-				window.onClick(e, e.target);
-				window.hideTooltip(this, e.target);
-			},
-			onRefresh: function(edata) {
-				if (edata.target === 'inserttable')
-					window.insertTable();
-
-				if (edata.target === 'insertshapes')
-					window.insertShapes();
-			}
-		});
-		toolbar.bind('touchstart', function(e) {
-			w2ui['editbar'].touchStarted = true;
-			var touchEvent = e.originalEvent;
-			if (touchEvent && touchEvent.touches.length > 1) {
-				L.DomEvent.preventDefault(e);
-			}
-		});
-
-		toolbar = $('#toolbar-search');
-		toolbar.w2toolbar({
-			name: 'searchbar',
-			tooltip: 'top',
-			items: [
-				{
-					type: 'html', id: 'search',
-					html: '<div id="search-input-group" style="padding: 3px 10px;" class="loleaflet-font">' +
-						'    <label for="search-input">Search:</label>' +
-						'    <input size="10" id="search-input"' +
-						'style="padding: 3px; border-radius: 2px; border: 1px solid silver"/>' +
-						'</div>'
-				},
-				{type: 'button', id: 'searchprev', img: 'prev', hint: _UNO('.uno:UpSearch'), disabled: true},
-				{type: 'button', id: 'searchnext', img: 'next', hint: _UNO('.uno:DownSearch'), disabled: true},
-				{type: 'button', id: 'cancelsearch', img: 'cancel', hint: _('Clear the search field'), hidden: true},
-				{type: 'html', id: 'left'},
-				{type: 'button', id: 'hidesearchbar', img: 'unfold', hint: _('Hide the search bar')}
-			],
-			onClick: function (e) {
-				window.onClick(e, e.target, e.item, e.subItem);
-			},
-			onRefresh: function () {
-				$('#search-input').off('input', window.onSearch).on('input', window.onSearch);
-				$('#search-input').off('keydown', window.onSearchKeyDown).on('keydown', window.onSearchKeyDown);
-			}
-		});
-
-		toolbar.bind('touchstart', function(e) {
-			w2ui['searchbar'].touchStarted = true;
-			var touchEvent = e.originalEvent;
-			if (touchEvent && touchEvent.touches.length > 1) {
-				L.DomEvent.preventDefault(e);
-			}
-		});
-
-		$(w2ui.searchbar.box).find('.w2ui-scroll-left, .w2ui-scroll-right').hide();
-		w2ui.searchbar.on('resize', function(target, e) {
-			e.isCancelled = true;
-		});
-
-		map.on('updatetoolbarcommandvalues', function() {
-			w2ui['editbar'].refresh();
-		});
-
-		map.on('showbusy', function(e) {
-			w2utils.lock(w2ui['actionbar'].box, e.label, true);
-		});
-
-		map.on('hidebusy', function() {
-			// If locked, unlock
-			if (w2ui['actionbar'].box.firstChild.className === 'w2ui-lock') {
-				w2utils.unlock(w2ui['actionbar'].box);
-			}
-		});
-
-		map.on('updatepermission', window.onUpdatePermission);
 	},
 
 	onAdd: function (map) {
@@ -296,6 +128,7 @@ L.ImpressTileLayer = L.TileLayer.extend({
 
 	onRemove: function (map) {
 		map.off('updatemaxbounds', this._onUpdateMaxBounds, this);
+		clearTimeout(this._previewInvalidator);
 	},
 
 	onAnnotationCancel: function () {
@@ -425,18 +258,28 @@ L.ImpressTileLayer = L.TileLayer.extend({
 	onOrientationChange: function () {
 		var container = L.DomUtil.get('presentation-controls-wrapper');
 		var preview = L.DomUtil.get('slide-sorter');
-		var control = $(preview).data('preview');
 
-		if (!container || !preview || !control) {
+		if (!container || !preview) {
 			return;
 		}
 
+		// Android change the orientation if the keyboard is visible
+		if (L.Browser.android) {
+			if (window.innerHeight < 2 * screen.height / 3) {
+				L.DomUtil.addClass(this._map.options.documentContainer, 'keyboard');
+				$(preview).hide();
+			} else {
+				L.DomUtil.removeClass(this._map.options.documentContainer, 'keyboard');
+				$(preview).show();
+			}
+		}
+
 		if (L.DomUtil.isPortrait() && $(preview).data('mCS').opt.axis !== 'x') {
 			$(preview).mCustomScrollbar('destroy');
-			control.createScrollbar('x');
+			this._preview.createScrollbar('x');
 		} else if (L.DomUtil.isLandscape() && $(preview).data('mCS').opt.axis !== 'y') {
 			$(preview).mCustomScrollbar('destroy');
-			control.createScrollbar('y');
+			this._preview.createScrollbar('y');
 		}
 
 	},
