@@ -3,19 +3,6 @@
  * L.Map is the central class of the API - it is used to create a map.
  */
 
-function moveObjectVertically(obj, diff) {
-	if (obj) {
-		var prevTop = obj.css('top');
-		if (prevTop) {
-			prevTop = parseInt(prevTop.slice(0, -2)) + diff;
-		}
-		else {
-			prevTop = 0 + diff;
-		}
-		obj.css({'top': String(prevTop) + 'px'});
-	}
-}
-
 function isAnyVexDialogActive() {
 	var res = false;
 	for (var vexId in vex.getAll()) {
@@ -24,15 +11,24 @@ function isAnyVexDialogActive() {
 	return res;
 }
 
-/* global vex revHistoryEnabled $ _ */
+/* global vex $ _ */
 L.Map = L.Evented.extend({
 
+	statics: {
+		THIS : undefined
+	},
+
 	options: {
 		crs: L.CRS.Simple,
 		center: [0, 0],
 		zoom: 10,
-		minZoom: 4,
-		maxZoom: 14,
+		// These zoom values are on a logarithmic scale. Each step away from the default 10
+		// (meaning 1 = 100%) is a multiplication by or division with pow(2,1/4). pow(2,1/4)
+		// is approximately 1.2. Thus 4 corresponds to six steps of division by pow(2,1/4) =
+		// 35%. 18 corresponds to 8 steps of multiplication by pow(2,1/4) = 400%. The
+		// percentages available are then rounded to the nearest five percent.
+		minZoom: 1,
+		maxZoom: 18,
 		maxBounds: L.latLngBounds([0, 0], [-100, 100]),
 		fadeAnimation: false, // Not useful for typing.
 		trackResize: true,
@@ -48,6 +44,12 @@ L.Map = L.Evented.extend({
 		cursorURL: 'images/cursors'
 	},
 
+	// Control.UIManager instance, set in main.js
+	uiManager: null,
+
+	// Control.LokDialog instance, is set in Control.UIManager.js
+	dialog: null,
+
 	lastActiveTime: Date.now(),
 
 	initialize: function (id, options) { // (HTMLElement or String, Object)
@@ -58,7 +60,8 @@ L.Map = L.Evented.extend({
 			this.options.documentContainer = L.DomUtil.get(this.options.documentContainer);
 		}
 
-		this._clip = L.clipboard(this);
+		if (!window.ThisIsTheiOSApp && !window.ThisIsTheAndroidApp)
+			this._clip = L.clipboard(this);
 		this._initContainer(id);
 		this._initLayout();
 
@@ -66,11 +69,12 @@ L.Map = L.Evented.extend({
 		this._onResize = L.bind(this._onResize, this);
 
 		// Start with readonly toolbars on desktop
-		if (!L.Browser.mobile) {
+		if (window.mode.isDesktop()) {
 			L.DomUtil.addClass(L.DomUtil.get('toolbar-wrapper'), 'readonly');
 		}
 
 		this._initEvents();
+		this._cacheSVG = [];
 
 		if (options.maxBounds) {
 			this.setMaxBounds(options.maxBounds);
@@ -108,8 +112,19 @@ L.Map = L.Evented.extend({
 		this._documentIdle = false;
 		this._helpTarget = null; // help page that fits best the current context
 		this._disableDefaultAction = {}; // The events for which the default handler is disabled and only issues postMessage.
+		this.showSidebar = false;
+
+		// Focusing:
+		//
+		// Cursor is visible or hidden (e.g. for graphic selection).
+		this._isCursorVisible = true;
+		// The ID of the window with focus. 0 for the document.
 		this._winId = 0;
+		// The object of the dialog, if any (must have .focus callable).
 		this._activeDialog = null;
+		// True only when searching within the doc, as we need to use winId==0.
+		this._isSearching = false;
+
 
 		vex.dialogID = -1;
 
@@ -117,9 +132,8 @@ L.Map = L.Evented.extend({
 
 		this.addHandler('keyboard', L.Map.Keyboard);
 		this.addHandler('dragging', L.Map.Drag);
-		if (L.Browser.touch && !L.Browser.pointer) {
+		if ((L.Browser.touch && !L.Browser.pointer) || (L.Browser.cypressTest && (window.mode.isMobile() || window.mode.isTablet()))) {
 			this.dragging.disable();
-			this.options.inertia = false;
 			this.dragging._draggable._manualDrag = true;
 			this._mainEvents('off');
 			this.addHandler('touchGesture', L.Map.TouchGesture);
@@ -137,15 +151,15 @@ L.Map = L.Evented.extend({
 		this._socket = L.socket(this);
 
 		var center = this.getCenter();
-		if (L.Browser.mobile) {
+		if (window.mode.isMobile() || window.mode.isTablet()) {
 			var doubledProgressHeight = 200;
 			var size = new L.point(screen.width, screen.height - doubledProgressHeight);
 			center = this.layerPointToLatLng(size._divideBy(2));
 		}
 		this._progressBar = L.progressOverlay(center, new L.point(150, 25));
 
-		this._clipboardContainer = L.clipboardContainer();
-		this.addLayer(this._clipboardContainer);
+		this._textInput = L.textInput();
+		this.addLayer(this._textInput);
 
 		if (window.mode.isMobile()) {
 			L.DomEvent.on(window, 'resize', function(e) {
@@ -170,16 +184,15 @@ L.Map = L.Evented.extend({
 
 			if (e.perm === 'readonly') {
 				L.DomUtil.addClass(this._container.parentElement, 'readonly');
-				if (!L.Browser.mobile) {
+				if (window.mode.isDesktop()) {
 					L.DomUtil.addClass(L.DomUtil.get('toolbar-wrapper'), 'readonly');
 				}
 				L.DomUtil.addClass(L.DomUtil.get('main-menu'), 'readonly');
 				L.DomUtil.addClass(L.DomUtil.get('presentation-controls-wrapper'), 'readonly');
 				L.DomUtil.addClass(L.DomUtil.get('spreadsheet-row-column-frame'), 'readonly');
-			}
-			else {
+			} else {
 				L.DomUtil.removeClass(this._container.parentElement, 'readonly');
-				if (!L.Browser.mobile) {
+				if (window.mode.isDesktop()) {
 					L.DomUtil.removeClass(L.DomUtil.get('toolbar-wrapper'), 'readonly');
 				}
 				L.DomUtil.removeClass(L.DomUtil.get('main-menu'), 'readonly');
@@ -191,37 +204,27 @@ L.Map = L.Evented.extend({
 			if (!this.initComplete) {
 				this._fireInitComplete('doclayerinit');
 			}
-			if (!L.Browser.mobile && this._docLayer._docType == 'text') {
+			if ((window.mode.isTablet() || window.mode.isDesktop()) && this._docLayer._docType == 'text') {
 				var interactiveRuler = this._permission === 'edit' ? true : false;
 				L.control.ruler({position:'topleft', interactive:interactiveRuler}).addTo(this);
 			}
-			var elem;
 			if (this._docLayer._docType === 'text') {
-				elem = L.DomUtil.get('spreadsheet-row-column-frame');
-				elem.parentNode.removeChild(elem);
-				elem = L.DomUtil.get('spreadsheet-toolbar');
-				elem.parentNode.removeChild(elem);
-				elem = L.DomUtil.get('presentation-controls-wrapper');
-				elem.parentNode.removeChild(elem);
+				L.DomUtil.remove(L.DomUtil.get('spreadsheet-row-column-frame'));
+				L.DomUtil.remove(L.DomUtil.get('spreadsheet-toolbar'));
+				L.DomUtil.remove(L.DomUtil.get('presentation-controls-wrapper'));
 			} else if (this._docLayer._docType === 'presentation') {
-				elem = L.DomUtil.get('spreadsheet-row-column-frame');
-				elem.parentNode.removeChild(elem);
-				elem = L.DomUtil.get('spreadsheet-toolbar');
-				elem.parentNode.removeChild(elem);
+				L.DomUtil.remove(L.DomUtil.get('spreadsheet-row-column-frame'));
+				L.DomUtil.remove(L.DomUtil.get('spreadsheet-toolbar'));
 			} else if (this._docLayer._docType === 'spreadsheet') {
-				elem = L.DomUtil.get('presentation-controls-wrapper');
-				elem.parentNode.removeChild(elem);
+				L.DomUtil.remove(L.DomUtil.get('presentation-controls-wrapper'));
 			}
 
-			// We need core's knowledge of whether it is a mobile phone or not (which is
-			// what .uno:LOKSetMobile does) to be in sync with the test in
-			// _onJSDialogMsg in TileLayer.js but we don't have the clout to do so
-			// except for the iOS app out of fear of breaking something.
-			if (L.Browser.mobile && (!window.ThisIsTheiOSApp || screen.width < 768))
+			// We need core's knowledge of whether it is a mobile phone
+			// or not to be in sync with the test in _onJSDialogMsg in TileLayer.js.
+			if (window.mode.isMobile())
 			{
 				this._size = new L.Point(0,0);
 				this._onResize();
-				this._socket.sendMessage('uno .uno:LOKSetMobile');
 			}
 		});
 		this.on('updatetoolbarcommandvalues', function(e) {
@@ -241,6 +244,11 @@ L.Map = L.Evented.extend({
 
 		this.on('editorgotfocus', this._onEditorGotFocus, this);
 
+		// Fired to signal that the input focus is being changed.
+		this.on('changefocuswidget', this._onChangeFocusWidget, this);
+
+		this.on('searchstart', this._onSearchStart, this);
+
 		// View info (user names and view ids)
 		this._viewInfo = {};
 		this._viewInfoByUserName = {};
@@ -292,18 +300,9 @@ L.Map = L.Evented.extend({
 				// Let the first page finish loading then load the sidebar.
 				var map = this;
 				setTimeout(function () {
-                    // This triggers all sidebar decks, so they would
-                    // be loaded and show rather quickly on first use.
-                    // Also, triggers sidebar window creation in the client.
-					map._socket.sendMessage('uno .uno:Sidebar');
-
-					// HACK: The initial state of sidebar is that the core
-					// thinks it is shown, so the command has to be triggered
-					// once again for it to be visible on the desktop
-					// (because the first .uno:Sidebar has actually hidden
-					// that)
-					if (!window.mode.isMobile() && !window.mode.isTablet() && !window.ThisIsAMobileApp) {
-						map._socket.sendMessage('uno .uno:Sidebar');
+					// Show the sidebar by default, but not on mobile.
+					if (window.mode.isDesktop() && !window.ThisIsAMobileApp) {
+						map._socket.sendMessage('uno .uno:SidebarShow');
 					}
 				}, 200);
 			}
@@ -401,7 +400,7 @@ L.Map = L.Evented.extend({
 			lastModButton.firstChild.innerHTML = '';
 			lastModButton.firstChild.appendChild(mainSpan);
 
-			if (revHistoryEnabled) {
+			if (L.Params.revHistoryEnabled) {
 				L.DomUtil.setStyle(lastModButton, 'cursor', 'pointer');
 			}
 		}
@@ -439,6 +438,9 @@ L.Map = L.Evented.extend({
 	},
 
 	showBusy: function(label, bar) {
+		if (window.ThisIsTheAndroidApp)
+			return;
+
 		// If document is already loaded, ask the toolbar widget to show busy
 		// status on the bottom statusbar
 		if (this._docLayer) {
@@ -449,6 +451,9 @@ L.Map = L.Evented.extend({
 	},
 
 	hideBusy: function () {
+		if (window.ThisIsTheAndroidApp)
+			return;
+
 		this.fire('hidebusy');
 		this._progressBar.end(this);
 	},
@@ -678,7 +683,6 @@ L.Map = L.Evented.extend({
 		if (this._docLayer) {
 			this.removeLayer(this._docLayer);
 		}
-		this.removeControls();
 		this._socket.close();
 		return this;
 	},
@@ -714,7 +718,10 @@ L.Map = L.Evented.extend({
 	},
 
 	getZoom: function () {
-		return this._zoom;
+		if (this._animatingZoom) // use animation target zoom
+			return this._animateToZoom;
+		else
+			return this._zoom;
 	},
 
 	getBounds: function () {
@@ -775,10 +782,22 @@ L.Map = L.Evented.extend({
 	},
 
 	getSize: function () {
+		var clientWidth = this._container.clientWidth;
+		var clientHeight = this._container.clientHeight;
+
+		if (window.updateMapSizeForWizard)
+		{
+			var wizardHeight = $('#mobile-wizard').height();
+			// the container has a bottom pixel set, it does not contain all the height
+			// we need it for calculating how much pixels the wizard covers on the map
+			var containerBottomPixels = parseInt($('#document-container').css('bottom'));
+			clientHeight -= wizardHeight - containerBottomPixels;
+		}
+
 		if (!this._size || this._sizeChanged) {
 			this._size = new L.Point(
-				this._container.clientWidth,
-				this._container.clientHeight);
+				clientWidth,
+				clientHeight);
 
 			this._sizeChanged = false;
 		}
@@ -811,15 +830,12 @@ L.Map = L.Evented.extend({
 		return this._container;
 	},
 
-	// Returns the instance of layer/marker/ClipboardContainer in this map.
-	getClipboardContainer: function getClipboardContainer() {
-		return this._clipboardContainer;
-	},
-
 	// We have one global winId that controls what window (dialog, sidebar, or
 	// the main document) has the actual focus.  0 means the document.
 	setWinId: function (id) {
 		console.log('winId set to: ' + id);
+		if (typeof id === 'string')
+			id = parseInt(id);
 		this._winId = id;
 	},
 
@@ -828,16 +844,27 @@ L.Map = L.Evented.extend({
 		return this._winId;
 	},
 
+	// Returns true iff the document has input focus,
+	// as opposed to a dialog, sidebar, formula bar, etc.
+	editorHasFocus: function () {
+		return this.getWinId() === 0;
+	},
+
+	// Returns true iff the formula-bar has the focus.
+	calcInputBarHasFocus: function () {
+		return !this.editorHasFocus() && this._activeDialog && this._activeDialog.isCalcInputBar(this.getWinId());
+	},
+
 	// TODO replace with universal implementation after refactoring projections
 
 	getZoomScale: function (toZoom, fromZoom) {
 		var crs = this.options.crs;
-		fromZoom = fromZoom === undefined ? this._zoom : fromZoom;
+		fromZoom = fromZoom === undefined ? this.getZoom() : fromZoom;
 		return crs.scale(toZoom) / crs.scale(fromZoom);
 	},
 
 	getScaleZoom: function (scale, fromZoom) {
-		fromZoom = fromZoom === undefined ? this._zoom : fromZoom;
+		fromZoom = fromZoom === undefined ? this.getZoom() : fromZoom;
 		return fromZoom + (Math.log(scale) / Math.log(1.2));
 	},
 
@@ -845,13 +872,13 @@ L.Map = L.Evented.extend({
 	// conversion methods
 
 	project: function (latlng, zoom) { // (LatLng[, Number]) -> Point
-		zoom = zoom === undefined ? this._zoom : zoom;
+		zoom = zoom === undefined ? this.getZoom() : zoom;
 		var projectedPoint = this.options.crs.latLngToPoint(L.latLng(latlng), zoom);
 		return new L.Point(L.round(projectedPoint.x, 1e-6), L.round(projectedPoint.y, 1e-6));
 	},
 
 	unproject: function (point, zoom) { // (Point[, Number]) -> LatLng
-		zoom = zoom === undefined ? this._zoom : zoom;
+		zoom = zoom === undefined ? this.getZoom() : zoom;
 		return this.options.crs.pointToLatLng(L.point(point), zoom);
 	},
 
@@ -902,17 +929,27 @@ L.Map = L.Evented.extend({
 		return this.layerPointToLatLng(this.mouseEventToLayerPoint(e));
 	},
 
-	focus: function () {
-		// Clicking or otherwise focusing the map should focus on the clipboard
-		// container in order for the user to input text (and on-screen keyboards
-		// to pop-up), unless the document is read only.
-		if (this._permission === 'edit') {
-			this._clipboardContainer.focus();
-		}
+	// Give the focus to the text input.
+	// @acceptInput (only on "mobile" (= mobile phone) or on iOS and Android in general) true if we want to
+	// accept key input, and show the virtual keyboard.
+	focus: function (acceptInput) {
+		this._textInput.focus(acceptInput);
+	},
+
+	// Lose focus to stop accepting keyboard input.
+	// On mobile, it will hide the virtual keyboard.
+	blur: function () {
+		this._textInput.blur();
 	},
 
 	hasFocus: function () {
-		return this._clipboardContainer.hasFocus();
+		return document.activeElement === this._textInput.activeElement();
+	},
+
+	// Returns true iff the textarea is enabled and we focused on it.
+	// On mobile, this signifies that the keyboard should be visible.
+	canAcceptKeyboardInput: function() {
+		return this._textInput.canAcceptKeyboardInput();
 	},
 
 	setHelpTarget: function(page) {
@@ -929,6 +966,10 @@ L.Map = L.Evented.extend({
 		this.fire('hyperlinkclicked', {url: helpURL});
 	},
 
+	isSearching: function() {
+		return this._isSearching;
+	},
+
 	_fireInitComplete: function (condition) {
 		if (this.initComplete) {
 			return;
@@ -953,13 +994,15 @@ L.Map = L.Evented.extend({
 			throw new Error('Map container is already initialized.');
 		}
 
-		this._resizeDetector = L.DomUtil.create('iframe', 'resize-detector', container);
+		if (window.mode.isDesktop()) {
+			this._resizeDetector = L.DomUtil.create('iframe', 'resize-detector', container);
+			this._resizeDetector.contentWindow.addEventListener('touchstart', L.DomEvent.preventDefault, {passive: false});
+			L.DomEvent.on(this._resizeDetector.contentWindow, 'contextmenu', L.DomEvent.preventDefault);
+		}
+
 		this._fileDownloader = L.DomUtil.create('iframe', '', container);
 		L.DomUtil.setStyle(this._fileDownloader, 'display', 'none');
 
-		this._resizeDetector.contentWindow.addEventListener('touchstart', L.DomEvent.preventDefault, {passive: false});
-
-		L.DomEvent.on(this._resizeDetector.contentWindow, 'contextmenu', L.DomEvent.preventDefault);
 		L.DomEvent.on(this._fileDownloader.contentWindow, 'contextmenu', L.DomEvent.preventDefault);
 		L.DomEvent.addListener(container, 'scroll', this._onScroll, this);
 		container._leaflet = true;
@@ -1006,6 +1049,7 @@ L.Map = L.Evented.extend({
 		this.createPane('overlayPane');
 		this.createPane('markerPane');
 		this.createPane('popupPane');
+		this.createPane('formfieldPane');
 
 		if (!this.options.markerZoomAnimation) {
 			L.DomUtil.addClass(panes.markerPane, 'leaflet-zoom-hide');
@@ -1087,8 +1131,10 @@ L.Map = L.Evented.extend({
 
 		this._mainEvents(onOff);
 
-		if (this.options.trackResize && this._resizeDetector.contentWindow) {
-			L.DomEvent[onOff](this._resizeDetector.contentWindow, 'resize', this._onResize, this);
+		if (this.options.trackResize) {
+			var winTarget = this._resizeDetector && this._resizeDetector.contentWindow ? this._resizeDetector.contentWindow :
+				window;
+			L.DomEvent[onOff](winTarget, 'resize', this._onResize, this);
 		}
 
 		L.DomEvent[onOff](window, 'blur', this._onLostFocus, this);
@@ -1099,13 +1145,14 @@ L.Map = L.Evented.extend({
 		L.Util.cancelAnimFrame(this._resizeRequest);
 		this._resizeRequest = L.Util.requestAnimFrame(
 			function () { this.invalidateSize({debounceMoveend: true}); }, this, false, this._container);
+		var deckOffset = 0;
 		var sidebarpanel = L.DomUtil.get('sidebar-panel');
 		if (sidebarpanel) {
 			var sidebar = sidebarpanel.children[0];
 			if (sidebar) {
 				sidebar.height = this._container.clientHeight - 10;
 				sidebar.style.height = sidebar.height + 'px';
-
+				deckOffset = sidebar.width;
 				// Fire the resize event to propagate the size change to WSD.
 				// .trigger isn't working, so doing it manually.
 				var event;
@@ -1125,6 +1172,22 @@ L.Map = L.Evented.extend({
 				}
 			}
 		}
+
+		if (this.dialog._calcInputBar && !this.dialog._calcInputBar.isPainting) {
+			var id = this.dialog._calcInputBar.id;
+			var calcInputbar = L.DomUtil.get('calc-inputbar');
+			if (calcInputbar) {
+				var calcInputbarContainer = calcInputbar.children[0];
+				if (calcInputbarContainer) {
+					var width = calcInputbarContainer.clientWidth - deckOffset;
+					var height = calcInputbarContainer.clientHeight;
+					if (width > 0 && height > 0) {
+						console.log('_onResize: container width: ' + width + ', container height: ' + height + ', _calcInputBar width: ' + this.dialog._calcInputBar.width);
+						this._socket.sendMessage('resizewindow ' + id + ' size=' + width + ',' + height);
+					}
+				}
+			}
+		}
 	},
 
 	makeActive: function() {
@@ -1161,7 +1224,7 @@ L.Map = L.Evented.extend({
 					}
 
 					this._startInactiveTimer();
-					if (!L.Browser.mobile) {
+					if (window.mode.isDesktop()) {
 						this.focus();
 					}
 					return vex.closeAll();
@@ -1172,7 +1235,7 @@ L.Map = L.Evented.extend({
 		}
 
 		this._startInactiveTimer();
-		if (!L.Browser.mobile) {
+		if (window.mode.isDesktop() && !isAnyVexDialogActive()) {
 			this.focus();
 		}
 		return false;
@@ -1310,61 +1373,69 @@ L.Map = L.Evented.extend({
 		}, map.options.outOfFocusTimeoutSecs * 1000);
 	},
 
-	// The editor lost focus (probably a dialog was created).
-	onEditorLostFocus: function onEditorLostFocus(dialog) {
+	// Change the focus to a dialog or editor.
+	// @dialog is the instance of the dialog class.
+	// @winId is the ID of the dialog/sidebar, or 0 for the editor.
+	// @acceptInput iff defined, map.focus is called and passed to it.
+	_changeFocusWidget: function (dialog, winId, acceptInput) {
 		if (!this._loaded) { return; }
 
-		var doclayer = this._docLayer;
-		if (doclayer)
-		{
-			doclayer._isFocused = false;
-			doclayer._updateCursorAndOverlay();
-		}
+		this.setWinId(winId);
+		this._activeDialog = dialog;
+		this._isSearching = false;
 
-		if (dialog) {
-			this._activeDialog = dialog;
+		if (this.editorHasFocus()) {
+			// The document has the focus.
+			var doclayer = this._docLayer;
+			if (doclayer)
+				doclayer._updateCursorAndOverlay();
+		} else if (acceptInput !== undefined) {
+			// A dialog has the focus.
+			this.focus(acceptInput);
+			this._textInput.hideCursor(); // The cursor is in the dialog.
 		}
 	},
 
 	// Our browser tab lost focus.
 	_onLostFocus: function () {
-		this.onEditorLostFocus();
 		this._deactivate();
 	},
 
 	// The editor got focus (probably a dialog closed or user clicked to edit).
 	_onEditorGotFocus: function() {
-		if (!this._loaded) { return; }
-
-		var map = this;
-		var doclayer = this._docLayer;
-		if (doclayer)
-		{
-			doclayer._isFocused = true;
-			// we restore the old cursor position by a small delay, so that if the user clicks
-			// inside the document we skip to restore it, so that the user does not see the cursor
-			// jumping from the old position to the new one
-			setTimeout(function () {
-				console.debug('apply focus change in timeout');
-				map.setWinId(0);
-				doclayer._updateCursorAndOverlay();
-			}, 300);
+		this._changeFocusWidget(null, 0);
+		if (this.dialog._calcInputBar) {
+			var inputBarId = this.dialog._calcInputBar.id;
+			this.dialog._updateTextSelection(inputBarId);
+			this.onFormulaBarBlur();
 		}
-
-		this._activeDialog = null;
 	},
 
 	// Our browser tab got focus.
 	_onGotFocus: function () {
-		if (this._activeDialog === null) {
-			this._onEditorGotFocus();
-		} else {
-			this._activeDialog.focus();
+		if (this.editorHasFocus()) {
+			this.fire('editorgotfocus');
+		}
+		else if (this._activeDialog) {
+			this._activeDialog.focus(this.getWinId());
 		}
 
 		this._activate();
 	},
 
+	// Event to change the focus to dialog or editor.
+	_onChangeFocusWidget: function (e) {
+		if (e.winId === 0) {
+			this._onEditorGotFocus();
+		} else {
+			this._changeFocusWidget(e.dialog, e.winId, e.acceptInput);
+		}
+	},
+
+	_onSearchStart: function () {
+		this._isSearching = true;
+	},
+
 	_onUpdateProgress: function (e) {
 		if (e.statusType === 'start') {
 			if (this._socket.socket.readyState === 1) {
@@ -1455,7 +1526,7 @@ L.Map = L.Evented.extend({
 			e.preventDefault();
 		}
 
-		// workaround for drawing shapes, wihout this shapes cannot be shrunken
+		// workaround for drawing shapes, without this shapes cannot be shrunken
 		if (target !== undefined && target._path !== undefined && type === 'mousemove') {
 			target = undefined;
 		}
@@ -1665,74 +1736,6 @@ L.Map = L.Evented.extend({
 				IsFollowEditor: followEditor}});
 	},
 
-	showMenubar: function() {
-		if (!this.isMenubarHidden())
-			return;
-		$('.main-nav').show();
-		if (window.closeButtonEnabled && !window.mode.isTablet()) {
-			$('#closebuttonwrapper').show();
-		}
-
-		var obj = $('.unfold');
-		obj.removeClass('unfold');
-		obj.addClass('fold');
-
-		moveObjectVertically($('#spreadsheet-row-column-frame'), 36);
-		moveObjectVertically($(this.options.documentContainer), 36);
-		moveObjectVertically($('#presentation-controls-wrapper'), 36);
-		moveObjectVertically($('#sidebar-dock-wrapper'), 36);
-	},
-
-	hideMenubar: function() {
-		if (this.isMenubarHidden())
-			return;
-		$('.main-nav').hide();
-		if (window.closeButtonEnabled) {
-			$('#closebuttonwrapper').hide();
-		}
-
-		var obj = $('.fold');
-		obj.removeClass('fold');
-		obj.addClass('unfold');
-
-		moveObjectVertically($('#spreadsheet-row-column-frame'), -36);
-		moveObjectVertically($(this.options.documentContainer), -36);
-		moveObjectVertically($('#presentation-controls-wrapper'), -36);
-		moveObjectVertically($('#sidebar-dock-wrapper'), -36);
-	},
-
-	isMenubarHidden: function() {
-		return $('.main-nav').css('display') === 'none';
-	},
-
-	toggleMenubar: function() {
-		if (this.isMenubarHidden())
-			this.showMenubar();
-		else
-			this.hideMenubar();
-	},
-
-	showRuler: function() {
-		$('.loleaflet-ruler').show();
-		$('#map').addClass('hasruler');
-	},
-
-	hideRuler: function() {
-		$('.loleaflet-ruler').hide();
-		$('#map').removeClass('hasruler');
-	},
-
-	toggleRuler: function() {
-		if (this.isRulerVisible())
-			this.hideRuler();
-		else
-			this.showRuler();
-	},
-
-	isRulerVisible: function() {
-		return $('.loleaflet-ruler').is(':visible');
-	},
-
 	hasObjectFocusDarkOverlay: function() {
 		return !!this.focusLayer;
 	},
@@ -1749,7 +1752,7 @@ L.Map = L.Evented.extend({
 			this.removeLayer(this.focusLayer);
 			this.focusLayer = null;
 		}
-	},
+	}
 });
 
 L.map = function (id, options) {
