@@ -39,7 +39,7 @@ var unoCommandsArray = {
 	ContinueNumbering:{text:{menu:_('Continue previous numbering'),},},
 	ControlCodes:{text:{menu:_('For~matting Marks'),},},
 	Copy:{global:{menu:_('Cop~y'),},},
-	CopyHyperlinkLocation:{text:{menu:_('Copy Hyperlink Location'),},},
+	CopyHyperlinkLocation:{global:{menu:_('Copy Hyperlink Location'),},},
 	CustomAnimation:{presentation:{menu:_('Animation'),},},
 	Cut:{global:{menu:_('~Cut'),},},
 	DataBarFormatDialog:{spreadsheet:{menu:_('Data Bar...'),},},
@@ -61,7 +61,7 @@ var unoCommandsArray = {
 	DeleteAllNotes:{global:{menu:_('Delete All Comments'),},spreadsheet:{menu:_('Delete All Comments'),},},
 	DeleteAuthor:{global:{menu:_('Delete All Comments by This Author'),},},
 	DeleteAxis:{global:{menu:_('Delete Axis'),},},
-	DeleteColumnbreak:{spreadsheet:{menu:_('Remove ~Column Break'),},},
+	DeleteColumnbreak:{spreadsheet:{menu:_('~Column Break'),},},
 	DeleteColumns:{presentation:{menu:_('Delete Column'),},spreadsheet:{menu:_('Delete Columns'),},text:{menu:_('~Columns'),},},
 	DeleteComment:{global:{menu:_('Delete Comment'),},},
 	DeleteDataLabel:{global:{menu:_('Delete Single Data Label'),},},
@@ -69,7 +69,7 @@ var unoCommandsArray = {
 	DeleteMajorGrid:{global:{menu:_('Delete Major Grid'),},},
 	DeleteMinorGrid:{global:{menu:_('Delete Minor Grid'),},},
 	DeleteNote:{spreadsheet:{menu:_('Delete Comment'),},},
-	DeleteRowbreak:{spreadsheet:{menu:_('Remove ~Row Break'),},},
+	DeleteRowbreak:{spreadsheet:{menu:_('~Row Break'),},},
 	DeleteRows:{presentation:{menu:_('Delete Row'),},spreadsheet:{menu:_('Delete Rows'),},text:{menu:_('~Rows'),},},
 	DeleteSlide:{presentation:{menu:_('~Delete Slide'),},},
 	DeleteTable:{text:{menu:_('~Table'),},},
@@ -154,24 +154,24 @@ var unoCommandsArray = {
 	InsertField:{text:{menu:_('~More Fields...'),},},
 	InsertFootnote:{text:{menu:_('~Footnote'),},},
 	InsertGraphic:{global:{context:_('Insert Image...'),menu:_('~Image...'),},},
-	InsertHardHyphen:{global:{menu:_('Non-br~eaking hyphen'),},},
+	InsertHardHyphen:{global:{menu:_('Insert non-br~eaking hyphen'),},},
 	InsertHeaderFooterMenu:{text:{menu:_('He~ader and Footer'),},},
 	InsertIndexesEntry:{text:{menu:_('~Index Entry...'),},},
-	InsertLRM:{global:{menu:_('~Left-to-right mark'),},},
+	InsertLRM:{global:{menu:_('~Left-to-right Mark'),},},
 	InsertMajorGrid:{global:{menu:_('Insert Major Grid'),},},
 	InsertMeanValue:{global:{menu:_('Insert Mean ~Value Line'),},},
 	InsertMenu:{global:{menu:_('~Insert'),},},
 	InsertMinorGrid:{global:{menu:_('Insert Minor Grid'),},},
 	InsertMultiIndex:{text:{menu:_('Table of Contents, ~Index or Bibliography...'),},},
 	InsertNeutralParagraph:{text:{menu:_('Insert Unnumbered Entry'),},},
-	InsertNonBreakingSpace:{global:{menu:_('~Non-breaking space'),},},
+	InsertNonBreakingSpace:{global:{menu:_('Insert ~non-breaking space'),},},
 	InsertObjectChart:{global:{context:_('Insert Chart'),menu:_('~Chart...'),},},
 	InsertPageCountField:{text:{menu:_('Page ~Count'),},},
 	InsertPageFooter:{text:{menu:_('Foote~r'),},},
 	InsertPageHeader:{text:{menu:_('He~ader'),},},
 	InsertPageNumberField:{global:{menu:_('~Page Numbers...'),},text:{menu:_('~Page Number'),},},
 	InsertPagebreak:{text:{menu:_('~Page Break'),},},
-	InsertRLM:{global:{menu:_('~Right-to-left mark'),},},
+	InsertRLM:{global:{menu:_('~Right-to-left Mark'),},},
 	InsertRemoveAxes:{global:{menu:_('Insert/Delete Axes...'),},},
 	InsertRowBreak:{spreadsheet:{menu:_('~Row Break'),},},
 	InsertRowsAfter:{presentation:{menu:_('Insert Row Below'),},spreadsheet:{context:_('Insert Rows ~Below'),menu:_('Rows ~Below'),},text:{menu:_('Rows ~Below'),},},
@@ -182,7 +182,7 @@ var unoCommandsArray = {
 	InsertSlideField:{presentation:{menu:_('~Slide Number'),},},
 	InsertSlideTitleField:{presentation:{menu:_('Slide Tit~le'),},},
 	InsertSlidesField:{presentation:{menu:_('Slide ~Count'),},},
-	InsertSoftHyphen:{global:{menu:_('S~oft hyphen'),},},
+	InsertSoftHyphen:{global:{menu:_('Insert s~oft Hyphen'),},},
 	InsertSymbol:{global:{context:_('Insert Special Character'),menu:_('S~pecial Character...'),},},
 	InsertTable:{presentation:{menu:_('~Table...'),},text:{menu:_('Insert ~Table...'),},},
 	InsertTimeField:{global:{menu:_('Time Field'),},text:{menu:_('~Time'),},},
@@ -194,8 +194,8 @@ var unoCommandsArray = {
 	InsertTrendline:{global:{menu:_('Insert Tre~nd Line...'),},},
 	InsertXErrorBars:{global:{menu:_('Insert X Error ~Bars...'),},},
 	InsertYErrorBars:{global:{menu:_('Insert Y Error ~Bars...'),},},
-	InsertZWNBSP:{global:{menu:_('No-width no ~break'),},},
-	InsertZWSP:{global:{menu:_('No-~width optional break'),},},
+	InsertZWNBSP:{global:{menu:_('No-width No ~Break'),},},
+	InsertZWSP:{global:{menu:_('No-~width Optional Break'),},},
 	Italic:{global:{menu:_('Italic'),},},
 	JumpDownThisLevel:{text:{menu:_('To Next Paragraph in Level'),},},
 	JumpUpThisLevel:{text:{menu:_('To Previous Paragraph in Level'),},},
@@ -224,7 +224,7 @@ var unoCommandsArray = {
 	OutlineBullet:{global:{menu:_('~Bullets and Numbering...'),},},
 	OutlineFont:{global:{menu:_('Outline'),},},
 	Overline:{global:{menu:_('Overline'),},},
-	PageDialog:{global:{menu:_('~Page...'),},text:{menu:_('~Page...'),},},
+	PageDialog:{global:{menu:_('~Page...'),},text:{menu:_('~Page Style...'),},},
 	PageDown:{text:{menu:_('Next Page'),},},
 	PageFormatDialog:{spreadsheet:{menu:_('~Page...'),},},
 	PageSetup:{presentation:{menu:_('Properties...'),},},
@@ -242,9 +242,9 @@ var unoCommandsArray = {
 	Redo:{global:{menu:_('~Redo'),},},
 	RejectAllTrackedChanges:{text:{menu:_('Reject All'),},},
 	Remove:{spreadsheet:{menu:_('~Delete Sheet...'),},},
-	RemoveHyperlink:{text:{menu:_('Remove Hyperlink'),},},
+	RemoveHyperlink:{global:{menu:_('~Remove Hyperlink'),},},
 	RemoveTableOf:{text:{menu:_('Delete index'),},},
-	RenameTable:{spreadsheet:{menu:_('~Rename Sheet...'),},},
+	RenameTable:{spreadsheet:{menu:_('Rename S~heet...'),},},
 	ReplyComment:{global:{menu:_('Reply Comment'),},},
 	ResetAllDataPoints:{global:{menu:_('Reset all Data Points'),},},
 	ResetAttributes:{global:{menu:_('~Clear Direct Formatting'),},spreadsheet:{context:_('Clear Direct Formatting'),menu:_('Clear ~Direct Formatting'),},text:{context:_('Clear Direct Formatting'),menu:_('Clear ~Direct Formatting'),},},
@@ -255,7 +255,7 @@ var unoCommandsArray = {
 	RotateRight:{text:{menu:_('Rotate 90° ~Right'),},},
 	Save:{global:{menu:_('~Save'),},},
 	SaveAs:{global:{menu:_('Save ~As...'),},},
-	SearchDialog:{global:{menu:_('Find & Rep~lace...'),},},
+	SearchDialog:{global:{menu:_('Find and Rep~lace...'),},},
 	SelectAll:{global:{menu:_('Select ~All'),},},
 	SelectBackground:{presentation:{menu:_('Set Background Image...'),},},
 	SelectTable:{presentation:{menu:_('~Select...'),},text:{menu:_('~Table'),},},
