@@ -47,6 +47,7 @@
 #include <Log.hpp>
 #include <Unit.hpp>
 #include <Util.hpp>
+#include "ProofKey.hpp"
 #include <common/FileUtil.hpp>
 #include <common/JsonUtil.hpp>
 
@@ -54,7 +55,8 @@ using std::size_t;
 
 bool StorageBase::FilesystemEnabled;
 bool StorageBase::WopiEnabled;
-bool StorageBase::SSLEnabled;
+bool StorageBase::SSLAsScheme = true;
+bool StorageBase::SSLEnabled = false;
 Util::RegexListMatcher StorageBase::WopiHosts;
 
 #if !MOBILEAPP
@@ -125,6 +127,10 @@ void StorageBase::initialize()
     // Init client
     Poco::Net::Context::Params sslClientParams;
 
+    // false default for upgrade to preserve legacy configuration
+    // in-config-file defaults are true.
+    SSLAsScheme = LOOLWSD::getConfigValue<bool>("storage.ssl.as_scheme", false);
+
     // Fallback to ssl.enable if not set - for back compatibility & simplicity.
     SSLEnabled = LOOLWSD::getConfigValue<bool>(
         "storage.ssl.enable", LOOLWSD::getConfigValue<bool>("ssl.enable", true));
@@ -299,7 +305,10 @@ std::unique_ptr<LocalStorage::LocalFileInfo> LocalStorage::getLocalFileInfo()
     return std::unique_ptr<LocalStorage::LocalFileInfo>(new LocalFileInfo({"localhost" + std::to_string(LastLocalStorageId), "LocalHost#" + std::to_string(LastLocalStorageId++)}));
 }
 
-std::string LocalStorage::loadStorageFileToLocal(const Authorization& /*auth*/, const std::string& /*templateUri*/)
+std::string LocalStorage::loadStorageFileToLocal(const Authorization& /*auth*/,
+                                                 const std::string& /*cookies*/,
+                                                 LockContext& /*lockCtx*/,
+                                                 const std::string& /*templateUri*/)
 {
 #if !MOBILEAPP
     // /chroot/jailId/user/doc/childId/file.ext
@@ -330,8 +339,7 @@ std::string LocalStorage::loadStorageFileToLocal(const Authorization& /*auth*/,
         // Fallback to copying.
         if (!Poco::File(getRootFilePath()).exists())
         {
-            LOG_INF("Copying " << LOOLWSD::anonymizeUrl(publicFilePath) << " to " << getRootFilePathAnonym());
-            Poco::File(publicFilePath).copyTo(getRootFilePath());
+            FileUtil::copyFileTo(publicFilePath, getRootFilePath());
             _isCopy = true;
         }
     }
@@ -363,17 +371,17 @@ std::string LocalStorage::loadStorageFileToLocal(const Authorization& /*auth*/,
 
 }
 
-StorageBase::SaveResult LocalStorage::saveLocalFileToStorage(const Authorization& /*auth*/, const std::string& /*saveAsPath*/, const std::string& /*saveAsFilename*/, bool /*isRename*/)
+StorageBase::SaveResult
+LocalStorage::saveLocalFileToStorage(const Authorization& /*auth*/, const std::string& /*cookies*/,
+                                     LockContext& /*lockCtx*/, const std::string& /*saveAsPath*/,
+                                     const std::string& /*saveAsFilename*/, bool /*isRename*/)
 {
     try
     {
         LOG_TRC("Saving local file to local file storage (isCopy: " << _isCopy << ") for " << getRootFilePathAnonym());
         // Copy the file back.
         if (_isCopy && Poco::File(getRootFilePath()).exists())
-        {
-            LOG_INF("Copying " << getRootFilePathAnonym() << " to " << LOOLWSD::anonymizeUrl(getUri().getPath()));
-            Poco::File(getRootFilePath()).copyTo(getUri().getPath());
-        }
+            FileUtil::copyFileTo(getRootFilePath(), getUri().getPath());
 
         // update its fileinfo object. This is used later to check if someone else changed the
         // document while we are/were editing it
@@ -395,15 +403,29 @@ StorageBase::SaveResult LocalStorage::saveLocalFileToStorage(const Authorization
 #if !MOBILEAPP
 
 Poco::Net::HTTPClientSession* StorageBase::getHTTPClientSession(const Poco::URI& uri)
- {
+{
+    bool useSSL = false;
+    if (SSLAsScheme)
+    {
+        // the WOPI URI itself should control whether we use SSL or not
+        // for whether we verify vs. certificates, cf. above
+        useSSL = uri.getScheme() != "http";
+    }
+    else
+    {
+        // We decoupled the Wopi communication from client communication because
+        // the Wopi communication must have an independent policy.
+        // So, we will use here only Storage settings.
+        useSSL = SSLEnabled || LOOLWSD::isSSLTermination();
+    }
     // We decoupled the Wopi communication from client communication because
     // the Wopi communication must have an independent policy.
     // So, we will use here only Storage settings.
-    return (SSLEnabled || LOOLWSD::isSSLTermination())
-         ? new Poco::Net::HTTPSClientSession(uri.getHost(), uri.getPort(),
-                                             Poco::Net::SSLManager::instance().defaultClientContext())
-         : new Poco::Net::HTTPClientSession(uri.getHost(), uri.getPort());
- }
+    return useSSL
+        ? new Poco::Net::HTTPSClientSession(uri.getHost(), uri.getPort(),
+                                            Poco::Net::SSLManager::instance().defaultClientContext())
+        : new Poco::Net::HTTPClientSession(uri.getHost(), uri.getPort());
+}
 
 namespace
 {
@@ -415,7 +437,7 @@ static void addStorageDebugCookie(Poco::Net::HTTPRequest& request)
     if (std::getenv("LOOL_STORAGE_COOKIE"))
     {
         Poco::Net::NameValueCollection nvcCookies;
-        std::vector<std::string> cookieTokens = LOOLProtocol::tokenize(std::string(std::getenv("LOOL_STORAGE_COOKIE")), ':');
+        StringVector cookieTokens = LOOLProtocol::tokenize(std::string(std::getenv("LOOL_STORAGE_COOKIE")), ':');
         if (cookieTokens.size() == 2)
         {
             nvcCookies.add(cookieTokens[0], cookieTokens[1]);
@@ -431,38 +453,87 @@ static void addStorageReuseCookie(Poco::Net::HTTPRequest& request, const std::st
     if (!reuseStorageCookies.empty())
     {
         Poco::Net::NameValueCollection nvcCookies;
-        std::vector<std::string> cookies = LOOLProtocol::tokenize(reuseStorageCookies, ':');
+        request.getCookies(nvcCookies); // Preserve existing cookies.
+
+        StringVector cookies = LOOLProtocol::tokenize(reuseStorageCookies, ':');
         for (auto cookie : cookies)
         {
-            std::vector<std::string> cookieTokens = LOOLProtocol::tokenize(cookie, '=');
+            StringVector cookieTokens = LOOLProtocol::tokenize(cookies.getParam(cookie), '=');
             if (cookieTokens.size() == 2)
             {
                 nvcCookies.add(cookieTokens[0], cookieTokens[1]);
-                LOG_DBG("Added storage reuse cookie [" << cookieTokens[0] << "=" << cookieTokens[1] << "].");
+                LOG_DBG("Added storage reuse cookie [" << cookieTokens[0] << '=' << cookieTokens[1] << "].");
             }
         }
+
         request.setCookies(nvcCookies);
     }
 }
 
+// access_token must be decoded
+void addWopiProof(Poco::Net::HTTPRequest& request, const Poco::URI& uri,
+                  const std::string& access_token)
+{
+    assert(!uri.isRelative());
+    for (const auto& header : GetProofHeaders(access_token, uri.toString()))
+        request.set(header.first, header.second);
+}
+
+std::map<std::string, std::string> GetQueryParams(const Poco::URI& uri)
+{
+    std::map<std::string, std::string> result;
+    for (const auto& param : uri.getQueryParameters())
+        result.emplace(param);
+    return result;
+}
+
 } // anonymous namespace
 
-std::unique_ptr<WopiStorage::WOPIFileInfo> WopiStorage::getWOPIFileInfo(const Authorization& auth)
+#endif // !MOBILEAPP
+
+void LockContext::initSupportsLocks()
+{
+#if MOBILEAPP
+    _supportsLocks = false;
+#else
+    if (_supportsLocks)
+        return;
+
+    // first time token setup
+    _supportsLocks = true;
+    _lockToken = "lool-lock" + Util::rng::getHexString(8);
+#endif
+}
+
+bool LockContext::needsRefresh(const std::chrono::steady_clock::time_point &now) const
+{
+    static int refreshSeconds = LOOLWSD::getConfigValue<int>("storage.wopi.locking.refresh", 900);
+    return _supportsLocks && _isLocked && refreshSeconds > 0 &&
+        std::chrono::duration_cast<std::chrono::seconds>
+        (now - _lastLockTime).count() >= refreshSeconds;
+}
+
+void LockContext::dumpState(std::ostream& os) const
+{
+    if (!_supportsLocks)
+        return;
+    os << "  lock:\n";
+    os << "    locked: " << _isLocked << "\n";
+    os << "    token: '" << _lockToken << "'\n";
+    os << "    last locked: " << Util::getSteadyClockAsString(_lastLockTime) << "\n";
+}
+
+#if !MOBILEAPP
+
+std::unique_ptr<WopiStorage::WOPIFileInfo> WopiStorage::getWOPIFileInfo(const Authorization& auth,
+                                                                        const std::string& cookies,
+                                                                        LockContext& lockCtx)
 {
     // update the access_token to the one matching to the session
     Poco::URI uriObject(getUri());
     auth.authorizeURI(uriObject);
     const std::string uriAnonym = LOOLWSD::anonymizeUrl(uriObject.toString());
-
-    std::string reuseStorageCookies;
-    for (const auto& param : uriObject.getQueryParameters())
-    {
-        if (param.first == "reuse_cookies")
-        {
-            reuseStorageCookies = param.second;
-            break;
-        }
-    }
+    std::map<std::string, std::string> params = GetQueryParams(uriObject);
 
     LOG_DBG("Getting info for wopi uri [" << uriAnonym << "].");
 
@@ -475,20 +546,32 @@ std::unique_ptr<WopiStorage::WOPIFileInfo> WopiStorage::getWOPIFileInfo(const Au
         auth.authorizeRequest(request);
         addStorageDebugCookie(request);
         if (_reuseCookies)
-            addStorageReuseCookie(request, reuseStorageCookies);
+            addStorageReuseCookie(request, cookies);
+        addWopiProof(request, uriObject, params["access_token"]);
         const auto startTime = std::chrono::steady_clock::now();
 
         std::unique_ptr<Poco::Net::HTTPClientSession> psession(getHTTPClientSession(uriObject));
+        Log::StreamLogger logger = Log::trace();
+        if (logger.enabled())
+        {
+            logger << "WOPI::CheckFileInfo request header for URI [" << uriAnonym << "]:\n";
+            for (const auto& pair : request)
+            {
+                logger << '\t' << pair.first << ": " << pair.second << " / ";
+            }
+
+            LOG_END(logger, true);
+        }
+
         psession->sendRequest(request);
 
         Poco::Net::HTTPResponse response;
         std::istream& rs = psession->receiveResponse(response);
         callDuration = (std::chrono::steady_clock::now() - startTime);
 
-        Log::StreamLogger logger = Log::trace();
         if (logger.enabled())
         {
-            logger << "WOPI::CheckFileInfo header for URI [" << uriAnonym << "]:\n";
+            logger << "WOPI::CheckFileInfo response header for URI [" << uriAnonym << "]:\n";
             for (const auto& pair : response)
             {
                 logger << '\t' << pair.first << ": " << pair.second << " / ";
@@ -511,6 +594,10 @@ std::unique_ptr<WopiStorage::WOPIFileInfo> WopiStorage::getWOPIFileInfo(const Au
                 pexc.displayText() << (pexc.nested() ? " (" + pexc.nested()->displayText() + ")" : ""));
         throw;
     }
+    catch (const BadRequestException& exc)
+    {
+        LOG_ERR("Cannot get file info from WOPI storage uri [" << uriAnonym << "]. Error:  Failed HTPP request authorization");
+    }
 
     // Parse the response.
     std::string filename;
@@ -538,6 +625,7 @@ std::unique_ptr<WopiStorage::WOPIFileInfo> WopiStorage::getWOPIFileInfo(const Au
     bool userCanNotWriteRelative = true;
     bool enableInsertRemoteImage = false;
     bool enableShare = false;
+    bool supportsLocks = false;
     bool supportsRename = false;
     bool userCanRename = false;
     std::string hideUserList("false");
@@ -598,7 +686,7 @@ std::unique_ptr<WopiStorage::WOPIFileInfo> WopiStorage::getWOPIFileInfo(const Au
                 object->remove("BaseFileName");
                 object->remove("TemplateSaveAs");
                 object->remove("TemplateSource");
-                 object->remove("OwnerId");
+                object->remove("OwnerId");
                 object->remove("UserId");
                 object->remove("UserFriendlyName");
             }
@@ -625,6 +713,7 @@ std::unique_ptr<WopiStorage::WOPIFileInfo> WopiStorage::getWOPIFileInfo(const Au
         JsonUtil::findJSONValue(object, "EnableInsertRemoteImage", enableInsertRemoteImage);
         JsonUtil::findJSONValue(object, "EnableShare", enableShare);
         JsonUtil::findJSONValue(object, "HideUserList", hideUserList);
+        JsonUtil::findJSONValue(object, "SupportsLocks", supportsLocks);
         JsonUtil::findJSONValue(object, "SupportsRename", supportsRename);
         JsonUtil::findJSONValue(object, "UserCanRename", userCanRename);
         bool booleanFlag = false;
@@ -650,17 +739,98 @@ std::unique_ptr<WopiStorage::WOPIFileInfo> WopiStorage::getWOPIFileInfo(const Au
     const std::chrono::system_clock::time_point modifiedTime = Util::iso8601ToTimestamp(lastModifiedTime, "LastModifiedTime");
     setFileInfo(FileInfo({filename, ownerId, modifiedTime, size}));
 
+    if (supportsLocks)
+        lockCtx.initSupportsLocks();
+
+    std::string overrideWatermarks = LOOLWSD::getConfigValue<std::string>("watermark.text", "");
+    if (!overrideWatermarks.empty())
+        watermarkText = overrideWatermarks;
+
     return std::unique_ptr<WopiStorage::WOPIFileInfo>(new WOPIFileInfo(
         {userId, obfuscatedUserId, userName, userExtraInfo, watermarkText, templateSaveAs, templateSource,
          canWrite, postMessageOrigin, hidePrintOption, hideSaveOption, hideExportOption,
          enableOwnerTermination, disablePrint, disableExport, disableCopy,
          disableInactiveMessages, downloadAsPostMessage, userCanNotWriteRelative, enableInsertRemoteImage, enableShare,
          hideUserList, disableChangeTrackingShow, disableChangeTrackingRecord,
-         hideChangeTrackingControls, supportsRename, userCanRename, callDuration}));
+         hideChangeTrackingControls, supportsLocks, supportsRename,
+         userCanRename, callDuration}));
+}
+
+bool WopiStorage::updateLockState(const Authorization& auth, const std::string& cookies,
+                                  LockContext& lockCtx, bool lock)
+{
+    if (!lockCtx._supportsLocks)
+        return true;
+
+    Poco::URI uriObject(getUri());
+    auth.authorizeURI(uriObject);
+
+    std::map<std::string, std::string> params = GetQueryParams(uriObject);
+
+    Poco::URI uriObjectAnonym(getUri());
+    uriObjectAnonym.setPath(LOOLWSD::anonymizeUrl(uriObjectAnonym.getPath()));
+    const std::string uriAnonym = uriObjectAnonym.toString();
+
+    const std::string wopiLog(lock ? "WOPI::Lock" : "WOPI::Unlock");
+    LOG_DBG(wopiLog << " requesting: " << uriAnonym);
+
+    try
+    {
+        std::unique_ptr<Poco::Net::HTTPClientSession> psession(getHTTPClientSession(uriObject));
+
+        Poco::Net::HTTPRequest request(Poco::Net::HTTPRequest::HTTP_POST, uriObject.getPathAndQuery(), Poco::Net::HTTPMessage::HTTP_1_1);
+        request.set("User-Agent", WOPI_AGENT_STRING);
+        auth.authorizeRequest(request);
+
+        request.set("X-WOPI-Override", lock ? "LOCK" : "UNLOCK");
+        request.set("X-WOPI-Lock", lockCtx._lockToken);
+        if (!getExtendedData().empty())
+            request.set("X-LOOL-WOPI-ExtendedData", getExtendedData());
+        addStorageDebugCookie(request);
+        if (_reuseCookies)
+            addStorageReuseCookie(request, cookies);
+        addWopiProof(request, uriObject, params["access_token"]);
+
+        psession->sendRequest(request);
+        Poco::Net::HTTPResponse response;
+        std::istream& rs = psession->receiveResponse(response);
+
+        std::ostringstream oss;
+        Poco::StreamCopier::copyStream(rs, oss);
+        std::string responseString = oss.str();
+
+        LOG_INF(wopiLog << " response: " << responseString <<
+                " status " << response.getStatus());
+
+        if (response.getStatus() == Poco::Net::HTTPResponse::HTTP_OK)
+        {
+            lockCtx._isLocked = lock;
+            lockCtx._lastLockTime = std::chrono::steady_clock::now();
+            return true;
+        }
+        else
+        {
+            LOG_WRN("Un-successful " << wopiLog << " with status " << response.getStatus() <<
+                    " and response: " << responseString);
+        }
+    }
+    catch (const Poco::Exception& pexc)
+    {
+        LOG_ERR("Cannot " << wopiLog << " uri [" << uriAnonym << "]. Error: " <<
+                pexc.displayText() << (pexc.nested() ? " (" + pexc.nested()->displayText() + ")" : ""));
+    }
+    catch (const BadRequestException& exc)
+    {
+        LOG_ERR("Cannot " << wopiLog << " uri [" << uriAnonym << "]. Error: Failed HTPP request authorization");
+    }
+    return false;
 }
 
 /// uri format: http://server/<...>/wopi*/files/<id>/content
-std::string WopiStorage::loadStorageFileToLocal(const Authorization& auth, const std::string& templateUri)
+std::string WopiStorage::loadStorageFileToLocal(const Authorization& auth,
+                                                const std::string& cookies,
+                                                LockContext& /*lockCtx*/,
+                                                const std::string& templateUri)
 {
     // WOPI URI to download files ends in '/contents'.
     // Add it here to get the payload instead of file info.
@@ -668,15 +838,7 @@ std::string WopiStorage::loadStorageFileToLocal(const Authorization& auth, const
     uriObject.setPath(uriObject.getPath() + "/contents");
     auth.authorizeURI(uriObject);
 
-    std::string reuseStorageCookies;
-    for (const auto& param : uriObject.getQueryParameters())
-    {
-        if (param.first == "reuse_cookies")
-        {
-            reuseStorageCookies = param.second;
-            break;
-        }
-    }
+    std::map<std::string, std::string> params = GetQueryParams(uriObject);
 
     Poco::URI uriObjectAnonym(getUri());
     uriObjectAnonym.setPath(LOOLWSD::anonymizeUrl(uriObjectAnonym.getPath()) + "/contents");
@@ -705,7 +867,8 @@ std::string WopiStorage::loadStorageFileToLocal(const Authorization& auth, const
         auth.authorizeRequest(request);
         addStorageDebugCookie(request);
         if (_reuseCookies)
-            addStorageReuseCookie(request, reuseStorageCookies);
+            addStorageReuseCookie(request, cookies);
+        addWopiProof(request, uriObject, params["access_token"]);
         psession->sendRequest(request);
 
         Poco::Net::HTTPResponse response;
@@ -741,10 +904,13 @@ std::string WopiStorage::loadStorageFileToLocal(const Authorization& auth, const
             ofs.close();
             LOG_INF("WOPI::GetFile downloaded " << getFileSize(getRootFilePath()) << " bytes from [" <<
                     uriAnonym << "] -> " << getRootFilePathAnonym() << " in " << diff.count() << "s");
-
             setLoaded(true);
+
             // Now return the jailed path.
-            return Poco::Path(getJailPath(), getFileInfo().getFilename()).toString();
+            if (LOOLWSD::NoCapsForKit)
+                return getRootFilePath();
+            else
+                return Poco::Path(getJailPath(), getFileInfo().getFilename()).toString();
         }
     }
     catch (const Poco::Exception& pexc)
@@ -753,11 +919,18 @@ std::string WopiStorage::loadStorageFileToLocal(const Authorization& auth, const
                 pexc.displayText() << (pexc.nested() ? " (" + pexc.nested()->displayText() + ")" : ""));
         throw;
     }
+    catch (const BadRequestException& exc)
+    {
+        LOG_ERR("Cannot load document from WOPI storage uri [" + uriAnonym + "]. Error: Failed HTPP request authorization");
+    }
 
     return "";
 }
 
-StorageBase::SaveResult WopiStorage::saveLocalFileToStorage(const Authorization& auth, const std::string& saveAsPath, const std::string& saveAsFilename, const bool isRename)
+StorageBase::SaveResult
+WopiStorage::saveLocalFileToStorage(const Authorization& auth, const std::string& cookies,
+                                    LockContext& lockCtx, const std::string& saveAsPath,
+                                    const std::string& saveAsFilename, const bool isRename)
 {
     // TODO: Check if this URI has write permission (canWrite = true)
 
@@ -771,21 +944,14 @@ StorageBase::SaveResult WopiStorage::saveLocalFileToStorage(const Authorization&
     uriObject.setPath(isSaveAs || isRename? uriObject.getPath(): uriObject.getPath() + "/contents");
     auth.authorizeURI(uriObject);
 
-    std::string reuseStorageCookies;
-    for (const auto& param : uriObject.getQueryParameters())
-    {
-        if (param.first == "reuse_cookies")
-        {
-            reuseStorageCookies = param.second;
-            break;
-        }
-    }
+    std::map<std::string, std::string> params = GetQueryParams(uriObject);
 
     const std::string uriAnonym = LOOLWSD::anonymizeUrl(uriObject.toString());
 
     LOG_INF("Uploading URI via WOPI [" << uriAnonym << "] from [" << filePathAnonym + "].");
 
     StorageBase::SaveResult saveResult(StorageBase::SaveResult::FAILED);
+    const auto startTime = std::chrono::steady_clock::now();
     try
     {
         std::unique_ptr<Poco::Net::HTTPClientSession> psession(getHTTPClientSession(uriObject));
@@ -798,6 +964,8 @@ StorageBase::SaveResult WopiStorage::saveLocalFileToStorage(const Authorization&
         {
             // normal save
             request.set("X-WOPI-Override", "PUT");
+            if (lockCtx._supportsLocks)
+                request.set("X-WOPI-Lock", lockCtx._lockToken);
             request.set("X-LOOL-WOPI-IsModifiedByUser", isUserModified()? "true": "false");
             request.set("X-LOOL-WOPI-IsAutosave", getIsAutosave()? "true": "false");
             request.set("X-LOOL-WOPI-IsExitSave", isExitSave()? "true": "false");
@@ -861,7 +1029,8 @@ StorageBase::SaveResult WopiStorage::saveLocalFileToStorage(const Authorization&
         request.setContentLength(size);
         addStorageDebugCookie(request);
         if (_reuseCookies)
-            addStorageReuseCookie(request, reuseStorageCookies);
+            addStorageReuseCookie(request, cookies);
+        addWopiProof(request, uriObject, params["access_token"]);
         std::ostream& os = psession->sendRequest(request);
 
         std::ifstream ifs(filePath);
@@ -870,6 +1039,8 @@ StorageBase::SaveResult WopiStorage::saveLocalFileToStorage(const Authorization&
         Poco::Net::HTTPResponse response;
         std::istream& rs = psession->receiveResponse(response);
 
+        _wopiSaveDuration = std::chrono::steady_clock::now() - startTime;
+
         std::ostringstream oss;
         Poco::StreamCopier::copyStream(rs, oss);
         std::string responseString = oss.str();
@@ -945,7 +1116,8 @@ StorageBase::SaveResult WopiStorage::saveLocalFileToStorage(const Authorization&
         {
             saveResult.setResult(StorageBase::SaveResult::DISKFULL);
         }
-        else if (response.getStatus() == Poco::Net::HTTPResponse::HTTP_UNAUTHORIZED)
+        else if (response.getStatus() == Poco::Net::HTTPResponse::HTTP_UNAUTHORIZED ||
+                 response.getStatus() == Poco::Net::HTTPResponse::HTTP_FORBIDDEN)
         {
             saveResult.setResult(StorageBase::SaveResult::UNAUTHORIZED);
         }
@@ -966,6 +1138,13 @@ StorageBase::SaveResult WopiStorage::saveLocalFileToStorage(const Authorization&
                 LOG_WRN("Invalid or missing JSON in " << wopiLog << " HTTP_CONFLICT response.");
             }
         }
+        else
+        {
+            // Internal server error, and other failures.
+            LOG_ERR("Unexpected response to " << wopiLog << " : " << response.getStatus() <<
+                    "Cannot save file to WOPI storage uri [" << uriAnonym << "]. Error: ");
+            saveResult.setResult(StorageBase::SaveResult::FAILED);
+        }
     }
     catch (const Poco::Exception& pexc)
     {
@@ -973,23 +1152,33 @@ StorageBase::SaveResult WopiStorage::saveLocalFileToStorage(const Authorization&
                 pexc.displayText() << (pexc.nested() ? " (" + pexc.nested()->displayText() + ")" : ""));
         saveResult.setResult(StorageBase::SaveResult::FAILED);
     }
+    catch (const BadRequestException& exc)
+    {
+        LOG_ERR("Cannot save file to WOPI storage uri [" + uriAnonym + "]. Error: Failed HTPP request authorization");
+    }
 
     return saveResult;
 }
 
-std::string WebDAVStorage::loadStorageFileToLocal(const Authorization& /*auth*/, const std::string& /*templateUri*/)
+std::string WebDAVStorage::loadStorageFileToLocal(const Authorization& /*auth*/,
+                                                  const std::string& /*cookies*/,
+                                                  LockContext& /*lockCtx*/,
+                                                  const std::string& /*templateUri*/)
 {
     // TODO: implement webdav GET.
     setLoaded(true);
     return getUri().toString();
 }
 
-StorageBase::SaveResult WebDAVStorage::saveLocalFileToStorage(const Authorization& /*auth*/, const std::string& /*saveAsPath*/, const std::string& /*saveAsFilename*/, bool /*isRename*/)
+StorageBase::SaveResult
+WebDAVStorage::saveLocalFileToStorage(const Authorization& /*auth*/, const std::string& /*cookies*/,
+                                      LockContext& /*lockCtx*/, const std::string& /*saveAsPath*/,
+                                      const std::string& /*saveAsFilename*/, bool /*isRename*/)
 {
     // TODO: implement webdav PUT.
     return StorageBase::SaveResult(StorageBase::SaveResult::OK);
 }
 
-#endif
+#endif // !MOBILEAPP
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
