@@ -321,15 +321,15 @@ void TileCache::invalidateTiles(const std::string& tiles, int normalizedViewId)
 
 std::pair<int, Util::Rectangle> TileCache::parseInvalidateMsg(const std::string& tiles)
 {
-    std::vector<std::string> tokens = LOOLProtocol::tokenize(tiles);
+    StringVector tokens = LOOLProtocol::tokenize(tiles);
 
-    assert(tokens.size() > 0 && tokens[0] == "invalidatetiles:");
+    assert(tokens.size() > 0 && tokens.equals(0, "invalidatetiles:"));
 
-    if (tokens.size() == 2 && tokens[1] == "EMPTY")
+    if (tokens.size() == 2 && tokens.equals(1, "EMPTY"))
     {
         return std::pair<int, Util::Rectangle>(-1, Util::Rectangle(0, 0, INT_MAX, INT_MAX));
     }
-    else if (tokens.size() == 3 && tokens[1] == "EMPTY,")
+    else if (tokens.size() == 3 && tokens.equals(1, "EMPTY,"))
     {
         int part = 0;
         if (stringToInteger(tokens[2], part))
@@ -656,7 +656,9 @@ void TileCache::TileBeingRendered::dumpState(std::ostream& os)
     for (const auto& it : _subscribers)
     {
         std::shared_ptr<ClientSession> session = it.lock();
-        os << "      " << session->getId() << " " << session->getUserId() << " " << session->getName() << "\n";
+        if (session)
+            os << "      " << session->getId() << ' ' << session->getUserId() << ' '
+               << session->getName() << '\n';
     }
 }
 
